import { IntegrationTaskKey, ExternalSource, TriggerIntegration, IO, ConnectionAuth, Json, IOTask, RunTaskOptions, RunTaskErrorCallback, EventSpecification, ExternalSourceTrigger } from '@trigger.dev/sdk';
import * as _octokit_types from '@octokit/types';
import { RequestRequestOptions } from '@octokit/types';
import { RequestError } from '@octokit/request-error';
import { IssuesEvent, IssuesOpenedEvent, IssuesAssignedEvent, IssueCommentEvent, StarEvent, StarCreatedEvent, RepositoryCreatedEvent, CreateEvent, PushEvent, PullRequestEvent, PullRequestReviewEvent } from '@octokit/webhooks-types';
import { Octokit } from 'octokit';

type ReactionContent = "+1" | "-1" | "laugh" | "confused" | "heart" | "hooray" | "rocket" | "eyes";
declare class Reactions {
    private runTask;
    constructor(runTask: GitHubRunTask);
    createForIssueComment(key: IntegrationTaskKey, params: {
        owner: string;
        repo: string;
        commentId: number;
        content: ReactionContent;
    }): GitHubReturnType<Octokit["rest"]["reactions"]["createForIssueComment"]>;
}

declare function createRepoEventSource(integration: Github): ExternalSource<Github, {
    owner: string;
    repo: string;
}, "HTTP", {}>;
declare function createOrgEventSource(integration: Github): ExternalSource<Github, {
    org: string;
}, "HTTP", {}>;

type AddIssueLabels = GitHubReturnType<Octokit["rest"]["issues"]["addLabels"]>;
declare class Issues {
    private runTask;
    constructor(runTask: GitHubRunTask);
    create(key: IntegrationTaskKey, params: {
        title: string;
        owner: string;
        repo: string;
    }): GitHubReturnType<Octokit["rest"]["issues"]["create"]>;
    addAssignees(key: IntegrationTaskKey, params: {
        owner: string;
        repo: string;
        issueNumber: number;
        assignees: string[];
    }): GitHubReturnType<Octokit["rest"]["issues"]["addAssignees"]>;
    addLabels(key: IntegrationTaskKey, params: {
        owner: string;
        repo: string;
        issueNumber: number;
        labels: string[];
    }): AddIssueLabels;
    createComment(key: IntegrationTaskKey, params: {
        body: string;
        owner: string;
        repo: string;
        issueNumber: number;
    }): GitHubReturnType<Octokit["rest"]["issues"]["createComment"]>;
    get(key: IntegrationTaskKey, params: {
        owner: string;
        repo: string;
        issueNumber: number;
    }): GitHubReturnType<Octokit["rest"]["issues"]["get"]>;
}

declare class Repos {
    private runTask;
    constructor(runTask: GitHubRunTask);
    get(key: IntegrationTaskKey, params: {
        owner: string;
        repo: string;
    }): GitHubReturnType<Octokit["rest"]["repos"]["get"]>;
    updateWebhook(key: IntegrationTaskKey, params: {
        owner: string;
        repo: string;
        hookId: number;
        url: string;
        secret: string;
        addEvents?: string[];
    }): GitHubReturnType<Octokit["rest"]["repos"]["updateWebhook"]>;
    createWebhook(key: IntegrationTaskKey, params: {
        owner: string;
        repo: string;
        url: string;
        secret: string;
        events: string[];
    }): GitHubReturnType<Octokit["rest"]["repos"]["createWebhook"]>;
    listWebhooks(key: IntegrationTaskKey, params: {
        owner: string;
        repo: string;
    }): GitHubReturnType<Octokit["rest"]["repos"]["listWebhooks"]>;
}

declare class Compound {
    private runTask;
    issues: Issues;
    reactions: Reactions;
    constructor(runTask: GitHubRunTask, issues: Issues, reactions: Reactions);
    createIssueCommentWithReaction(key: IntegrationTaskKey, params: {
        body: string;
        owner: string;
        repo: string;
        issueNumber: number;
        reaction: ReactionContent;
    }): GitHubReturnType<Octokit["rest"]["issues"]["createComment"]>;
}

declare class Orgs {
    private runTask;
    constructor(runTask: GitHubRunTask);
    updateWebhook(key: IntegrationTaskKey, params: {
        org: string;
        hookId: number;
        url: string;
        secret: string;
        addEvents?: string[];
    }): GitHubReturnType<Octokit["rest"]["orgs"]["updateWebhook"]>;
    createWebhook(key: IntegrationTaskKey, params: {
        org: string;
        url: string;
        secret: string;
        events: string[];
    }): GitHubReturnType<Octokit["rest"]["orgs"]["createWebhook"]>;
    listWebhooks(key: IntegrationTaskKey, params: {
        org: string;
    }): GitHubReturnType<Octokit["rest"]["orgs"]["listWebhooks"]>;
}

type Endcoding = "utf-8" | "base-64";
type AuthorContent = {
    name: string;
    email: string;
    date?: string;
};
type CommitterContent = {
    name?: string;
    email?: string;
    date?: string;
};
type TagType = "commit" | "tree" | "blob";
type TaggerContent = {
    name: string;
    email: string;
    date?: string;
};
type TreeType = {
    path?: string | undefined;
    mode?: "100644" | "100755" | "040000" | "160000" | "120000" | undefined;
    type?: "commit" | "tree" | "blob" | undefined;
    sha?: string | null | undefined;
    content?: string | undefined;
};
declare class Git {
    private runTask;
    constructor(runTask: GitHubRunTask);
    createBlob(key: IntegrationTaskKey, params: {
        owner: string;
        repo: string;
        content: string;
        encoding?: Endcoding;
    }): GitHubReturnType<Octokit["rest"]["git"]["createBlob"]>;
    getBlob(key: IntegrationTaskKey, params: {
        owner: string;
        repo: string;
        fileSHA: string;
    }): GitHubReturnType<Octokit["rest"]["git"]["getBlob"]>;
    createCommit(key: IntegrationTaskKey, params: {
        owner: string;
        repo: string;
        message: string;
        tree: string;
        parents?: string[];
        author?: AuthorContent;
        committer?: CommitterContent;
        signature?: string;
    }): GitHubReturnType<Octokit["rest"]["git"]["createCommit"]>;
    getCommit(key: IntegrationTaskKey, params: {
        owner: string;
        repo: string;
        commitSHA: string;
    }): GitHubReturnType<Octokit["rest"]["git"]["getCommit"]>;
    listMatchingRefs(key: IntegrationTaskKey, params: {
        owner: string;
        repo: string;
        ref: string;
    }): GitHubReturnType<Octokit["rest"]["git"]["listMatchingRefs"]>;
    getRef(key: IntegrationTaskKey, params: {
        owner: string;
        repo: string;
        ref: string;
    }): GitHubReturnType<Octokit["rest"]["git"]["getRef"]>;
    createRef(key: IntegrationTaskKey, params: {
        owner: string;
        repo: string;
        ref: string;
        sha: string;
    }): GitHubReturnType<Octokit["rest"]["git"]["createRef"]>;
    updateRef(key: IntegrationTaskKey, params: {
        owner: string;
        repo: string;
        ref: string;
        sha: string;
        force?: boolean;
    }): GitHubReturnType<Octokit["rest"]["git"]["updateRef"]>;
    deleteRef(key: IntegrationTaskKey, params: {
        owner: string;
        repo: string;
        ref: string;
    }): GitHubReturnType<Octokit["rest"]["git"]["deleteRef"]>;
    createTag(key: IntegrationTaskKey, params: {
        owner: string;
        repo: string;
        tag: string;
        message: string;
        object: string;
        type: TagType;
        tagger?: TaggerContent;
    }): GitHubReturnType<Octokit["rest"]["git"]["createTag"]>;
    getTag(key: IntegrationTaskKey, params: {
        owner: string;
        repo: string;
        tagSHA: string;
    }): GitHubReturnType<Octokit["rest"]["git"]["getTag"]>;
    createTree(key: IntegrationTaskKey, params: {
        owner: string;
        repo: string;
        tree: TreeType[];
        baseTree?: string;
    }): GitHubReturnType<Octokit["rest"]["git"]["createTree"]>;
    getTree(key: IntegrationTaskKey, params: {
        owner: string;
        repo: string;
        treeSHA: string;
        recursive?: string;
    }): GitHubReturnType<Octokit["rest"]["git"]["getTree"]>;
}

type GithubIntegrationOptions = {
    id: string;
    token?: string;
    octokitRequest?: RequestRequestOptions;
};
type GithubSources = {
    repo: ReturnType<typeof createRepoEventSource>;
    org: ReturnType<typeof createOrgEventSource>;
};
type GithubTriggers = {
    repo: ReturnType<typeof createRepoTrigger>;
    org: ReturnType<typeof createOrgTrigger>;
};
type GitHubRunTask = InstanceType<typeof Github>["runTask"];
type GitHubReturnType<T extends (params: any) => Promise<{
    data: K;
}>, K = any> = Promise<Awaited<ReturnType<T>>["data"]>;
declare class Github implements TriggerIntegration {
    private options;
    _repoSource: ReturnType<typeof createRepoEventSource>;
    _orgSource: ReturnType<typeof createOrgEventSource>;
    _repoTrigger: ReturnType<typeof createRepoTrigger>;
    _orgTrigger: ReturnType<typeof createOrgTrigger>;
    constructor(options: GithubIntegrationOptions);
    get id(): string;
    get metadata(): {
        name: string;
        id: string;
    };
    get authSource(): "LOCAL" | "HOSTED";
    cloneForRun(io: IO, connectionKey: string, auth?: ConnectionAuth): Github;
    get sources(): GithubSources;
    get triggers(): GithubTriggers;
    runTask<T, TResult extends Json<T> | void>(key: IntegrationTaskKey, callback: (client: Octokit, task: IOTask, io: IO) => Promise<TResult>, options?: RunTaskOptions, errorCallback?: RunTaskErrorCallback): Promise<TResult>;
    get issues(): Issues;
    get repos(): Repos;
    get reactions(): Reactions;
    get compound(): Compound;
    get orgs(): Orgs;
    get git(): Git;
    createIssue: (key: IntegrationTaskKey, params: {
        title: string;
        owner: string;
        repo: string;
    }) => GitHubReturnType<{
        (params?: (_octokit_types.RequestParameters & Omit<{
            owner: string;
            repo: string;
        } & {
            title: string | number;
            body?: string | undefined;
            assignee?: string | null | undefined;
            milestone?: string | number | undefined;
            labels?: (string | {
                id?: number | undefined;
                name?: string | undefined;
                description?: string | null | undefined;
                color?: string | null | undefined;
            })[] | undefined;
            assignees?: string[] | undefined;
        }, "headers" | "baseUrl" | "mediaType">) | undefined): Promise<_octokit_types.OctokitResponse<{
            id: number;
            node_id: string;
            url: string;
            repository_url: string;
            labels_url: string;
            comments_url: string;
            events_url: string;
            html_url: string;
            number: number;
            state: string;
            state_reason?: "reopened" | "completed" | "not_planned" | null | undefined;
            title: string;
            body?: string | null | undefined;
            user: {
                name?: string | null | undefined;
                email?: string | null | undefined;
                login: string;
                id: number;
                node_id: string;
                avatar_url: string;
                gravatar_id: string | null;
                url: string;
                html_url: string;
                followers_url: string;
                following_url: string;
                gists_url: string;
                starred_url: string;
                subscriptions_url: string;
                organizations_url: string;
                repos_url: string;
                events_url: string;
                received_events_url: string;
                type: string;
                site_admin: boolean;
                starred_at?: string | undefined;
            } | null;
            labels: (string | {
                id?: number | undefined;
                node_id?: string | undefined;
                url?: string | undefined;
                name?: string | undefined;
                description?: string | null | undefined;
                color?: string | null | undefined;
                default?: boolean | undefined;
            })[];
            assignee: {
                name?: string | null | undefined;
                email?: string | null | undefined;
                login: string;
                id: number;
                node_id: string;
                avatar_url: string;
                gravatar_id: string | null;
                url: string;
                html_url: string;
                followers_url: string;
                following_url: string;
                gists_url: string;
                starred_url: string;
                subscriptions_url: string;
                organizations_url: string;
                repos_url: string;
                events_url: string;
                received_events_url: string;
                type: string;
                site_admin: boolean;
                starred_at?: string | undefined;
            } | null;
            assignees?: {
                name?: string | null | undefined;
                email?: string | null | undefined;
                login: string;
                id: number;
                node_id: string;
                avatar_url: string;
                gravatar_id: string | null;
                url: string;
                html_url: string;
                followers_url: string;
                following_url: string;
                gists_url: string;
                starred_url: string;
                subscriptions_url: string;
                organizations_url: string;
                repos_url: string;
                events_url: string;
                received_events_url: string;
                type: string;
                site_admin: boolean;
                starred_at?: string | undefined;
            }[] | null | undefined;
            milestone: {
                url: string;
                html_url: string;
                labels_url: string;
                id: number;
                node_id: string;
                number: number;
                state: "open" | "closed";
                title: string;
                description: string | null;
                creator: {
                    name?: string | null | undefined;
                    email?: string | null | undefined;
                    login: string;
                    id: number;
                    node_id: string;
                    avatar_url: string;
                    gravatar_id: string | null;
                    url: string;
                    html_url: string;
                    followers_url: string;
                    following_url: string;
                    gists_url: string;
                    starred_url: string;
                    subscriptions_url: string;
                    organizations_url: string;
                    repos_url: string;
                    events_url: string;
                    received_events_url: string;
                    type: string;
                    site_admin: boolean;
                    starred_at?: string | undefined;
                } | null;
                open_issues: number;
                closed_issues: number;
                created_at: string;
                updated_at: string;
                closed_at: string | null;
                due_on: string | null;
            } | null;
            locked: boolean;
            active_lock_reason?: string | null | undefined;
            comments: number;
            pull_request?: {
                merged_at?: string | null | undefined;
                diff_url: string | null;
                html_url: string | null;
                patch_url: string | null;
                url: string | null;
            } | undefined;
            closed_at: string | null;
            created_at: string;
            updated_at: string;
            draft?: boolean | undefined;
            closed_by?: {
                name?: string | null | undefined;
                email?: string | null | undefined;
                login: string;
                id: number;
                node_id: string;
                avatar_url: string;
                gravatar_id: string | null;
                url: string;
                html_url: string;
                followers_url: string;
                following_url: string;
                gists_url: string;
                starred_url: string;
                subscriptions_url: string;
                organizations_url: string;
                repos_url: string;
                events_url: string;
                received_events_url: string;
                type: string;
                site_admin: boolean;
                starred_at?: string | undefined;
            } | null | undefined;
            body_html?: string | undefined;
            body_text?: string | undefined;
            timeline_url?: string | undefined;
            repository?: {
                id: number;
                node_id: string;
                name: string;
                full_name: string;
                license: {
                    key: string;
                    name: string;
                    url: string | null;
                    spdx_id: string | null;
                    node_id: string;
                    html_url?: string | undefined;
                } | null;
                organization?: {
                    name?: string | null | undefined;
                    email?: string | null | undefined;
                    login: string;
                    id: number;
                    node_id: string;
                    avatar_url: string;
                    gravatar_id: string | null;
                    url: string;
                    html_url: string;
                    followers_url: string;
                    following_url: string;
                    gists_url: string;
                    starred_url: string;
                    subscriptions_url: string;
                    organizations_url: string;
                    repos_url: string;
                    events_url: string;
                    received_events_url: string;
                    type: string;
                    site_admin: boolean;
                    starred_at?: string | undefined;
                } | null | undefined;
                forks: number;
                permissions?: {
                    admin: boolean;
                    pull: boolean;
                    triage?: boolean | undefined;
                    push: boolean;
                    maintain?: boolean | undefined;
                } | undefined;
                owner: {
                    name?: string | null | undefined;
                    email?: string | null | undefined;
                    login: string;
                    id: number;
                    node_id: string;
                    avatar_url: string;
                    gravatar_id: string | null;
                    url: string;
                    html_url: string;
                    followers_url: string;
                    following_url: string;
                    gists_url: string;
                    starred_url: string;
                    subscriptions_url: string;
                    organizations_url: string;
                    repos_url: string;
                    events_url: string;
                    received_events_url: string;
                    type: string;
                    site_admin: boolean;
                    starred_at?: string | undefined;
                };
                private: boolean;
                html_url: string;
                description: string | null;
                fork: boolean;
                url: string;
                archive_url: string;
                assignees_url: string;
                blobs_url: string;
                branches_url: string;
                collaborators_url: string;
                comments_url: string;
                commits_url: string;
                compare_url: string;
                contents_url: string;
                contributors_url: string;
                deployments_url: string;
                downloads_url: string;
                events_url: string;
                forks_url: string;
                git_commits_url: string;
                git_refs_url: string;
                git_tags_url: string;
                git_url: string;
                issue_comment_url: string;
                issue_events_url: string;
                issues_url: string;
                keys_url: string;
                labels_url: string;
                languages_url: string;
                merges_url: string;
                milestones_url: string;
                notifications_url: string;
                pulls_url: string;
                releases_url: string;
                ssh_url: string;
                stargazers_url: string;
                statuses_url: string;
                subscribers_url: string;
                subscription_url: string;
                tags_url: string;
                teams_url: string;
                trees_url: string;
                clone_url: string;
                mirror_url: string | null;
                hooks_url: string;
                svn_url: string;
                homepage: string | null;
                language: string | null;
                forks_count: number;
                stargazers_count: number;
                watchers_count: number;
                size: number;
                default_branch: string;
                open_issues_count: number;
                is_template?: boolean | undefined;
                topics?: string[] | undefined;
                has_issues: boolean;
                has_projects: boolean;
                has_wiki: boolean;
                has_pages: boolean;
                has_downloads: boolean;
                has_discussions?: boolean | undefined;
                archived: boolean;
                disabled: boolean;
                visibility?: string | undefined;
                pushed_at: string | null;
                created_at: string | null;
                updated_at: string | null;
                allow_rebase_merge?: boolean | undefined;
                template_repository?: {
                    id?: number | undefined;
                    node_id?: string | undefined;
                    name?: string | undefined;
                    full_name?: string | undefined;
                    owner?: {
                        login?: string | undefined;
                        id?: number | undefined;
                        node_id?: string | undefined;
                        avatar_url?: string | undefined;
                        gravatar_id?: string | undefined;
                        url?: string | undefined;
                        html_url?: string | undefined;
                        followers_url?: string | undefined;
                        following_url?: string | undefined;
                        gists_url?: string | undefined;
                        starred_url?: string | undefined;
                        subscriptions_url?: string | undefined;
                        organizations_url?: string | undefined;
                        repos_url?: string | undefined;
                        events_url?: string | undefined;
                        received_events_url?: string | undefined;
                        type?: string | undefined;
                        site_admin?: boolean | undefined;
                    } | undefined;
                    private?: boolean | undefined;
                    html_url?: string | undefined;
                    description?: string | undefined;
                    fork?: boolean | undefined;
                    url?: string | undefined;
                    archive_url?: string | undefined;
                    assignees_url?: string | undefined;
                    blobs_url?: string | undefined;
                    branches_url?: string | undefined;
                    collaborators_url?: string | undefined;
                    comments_url?: string | undefined;
                    commits_url?: string | undefined;
                    compare_url?: string | undefined;
                    contents_url?: string | undefined;
                    contributors_url?: string | undefined;
                    deployments_url?: string | undefined;
                    downloads_url?: string | undefined;
                    events_url?: string | undefined;
                    forks_url?: string | undefined;
                    git_commits_url?: string | undefined;
                    git_refs_url?: string | undefined;
                    git_tags_url?: string | undefined;
                    git_url?: string | undefined;
                    issue_comment_url?: string | undefined;
                    issue_events_url?: string | undefined;
                    issues_url?: string | undefined;
                    keys_url?: string | undefined;
                    labels_url?: string | undefined;
                    languages_url?: string | undefined;
                    merges_url?: string | undefined;
                    milestones_url?: string | undefined;
                    notifications_url?: string | undefined;
                    pulls_url?: string | undefined;
                    releases_url?: string | undefined;
                    ssh_url?: string | undefined;
                    stargazers_url?: string | undefined;
                    statuses_url?: string | undefined;
                    subscribers_url?: string | undefined;
                    subscription_url?: string | undefined;
                    tags_url?: string | undefined;
                    teams_url?: string | undefined;
                    trees_url?: string | undefined;
                    clone_url?: string | undefined;
                    mirror_url?: string | undefined;
                    hooks_url?: string | undefined;
                    svn_url?: string | undefined;
                    homepage?: string | undefined;
                    language?: string | undefined;
                    forks_count?: number | undefined;
                    stargazers_count?: number | undefined;
                    watchers_count?: number | undefined;
                    size?: number | undefined;
                    default_branch?: string | undefined;
                    open_issues_count?: number | undefined;
                    is_template?: boolean | undefined;
                    topics?: string[] | undefined;
                    has_issues?: boolean | undefined;
                    has_projects?: boolean | undefined;
                    has_wiki?: boolean | undefined;
                    has_pages?: boolean | undefined;
                    has_downloads?: boolean | undefined;
                    archived?: boolean | undefined;
                    disabled?: boolean | undefined;
                    visibility?: string | undefined;
                    pushed_at?: string | undefined;
                    created_at?: string | undefined;
                    updated_at?: string | undefined;
                    permissions?: {
                        admin?: boolean | undefined;
                        maintain?: boolean | undefined;
                        push?: boolean | undefined;
                        triage?: boolean | undefined;
                        pull?: boolean | undefined;
                    } | undefined;
                    allow_rebase_merge?: boolean | undefined;
                    temp_clone_token?: string | undefined;
                    allow_squash_merge?: boolean | undefined;
                    allow_auto_merge?: boolean | undefined;
                    delete_branch_on_merge?: boolean | undefined;
                    allow_update_branch?: boolean | undefined;
                    use_squash_pr_title_as_default?: boolean | undefined;
                    squash_merge_commit_title?: "PR_TITLE" | "COMMIT_OR_PR_TITLE" | undefined;
                    squash_merge_commit_message?: "COMMIT_MESSAGES" | "PR_BODY" | "BLANK" | undefined;
                    merge_commit_title?: "MERGE_MESSAGE" | "PR_TITLE" | undefined;
                    merge_commit_message?: "PR_TITLE" | "PR_BODY" | "BLANK" | undefined;
                    allow_merge_commit?: boolean | undefined;
                    subscribers_count?: number | undefined;
                    network_count?: number | undefined;
                } | null | undefined;
                temp_clone_token?: string | undefined;
                allow_squash_merge?: boolean | undefined;
                allow_auto_merge?: boolean | undefined;
                delete_branch_on_merge?: boolean | undefined;
                allow_update_branch?: boolean | undefined;
                use_squash_pr_title_as_default?: boolean | undefined;
                squash_merge_commit_title?: "PR_TITLE" | "COMMIT_OR_PR_TITLE" | undefined;
                squash_merge_commit_message?: "COMMIT_MESSAGES" | "PR_BODY" | "BLANK" | undefined;
                merge_commit_title?: "MERGE_MESSAGE" | "PR_TITLE" | undefined;
                merge_commit_message?: "PR_TITLE" | "PR_BODY" | "BLANK" | undefined;
                allow_merge_commit?: boolean | undefined;
                allow_forking?: boolean | undefined;
                web_commit_signoff_required?: boolean | undefined;
                subscribers_count?: number | undefined;
                network_count?: number | undefined;
                open_issues: number;
                watchers: number;
                master_branch?: string | undefined;
                starred_at?: string | undefined;
                anonymous_access_enabled?: boolean | undefined;
            } | undefined;
            performed_via_github_app?: {
                id: number;
                slug?: string | undefined;
                node_id: string;
                owner: {
                    name?: string | null | undefined;
                    email?: string | null | undefined;
                    login: string;
                    id: number;
                    node_id: string;
                    avatar_url: string;
                    gravatar_id: string | null;
                    url: string;
                    html_url: string;
                    followers_url: string;
                    following_url: string;
                    gists_url: string;
                    starred_url: string;
                    subscriptions_url: string;
                    organizations_url: string;
                    repos_url: string;
                    events_url: string;
                    received_events_url: string;
                    type: string;
                    site_admin: boolean;
                    starred_at?: string | undefined;
                } | null;
                name: string;
                description: string | null;
                external_url: string;
                html_url: string;
                created_at: string;
                updated_at: string;
                permissions: {
                    [key: string]: string | undefined;
                    issues?: string | undefined;
                    checks?: string | undefined;
                    metadata?: string | undefined;
                    contents?: string | undefined;
                    deployments?: string | undefined;
                };
                events: string[];
                installations_count?: number | undefined;
                client_id?: string | undefined;
                client_secret?: string | undefined;
                webhook_secret?: string | null | undefined;
                pem?: string | undefined;
            } | null | undefined;
            author_association: "MEMBER" | "NONE" | "COLLABORATOR" | "CONTRIBUTOR" | "FIRST_TIMER" | "FIRST_TIME_CONTRIBUTOR" | "MANNEQUIN" | "OWNER";
            reactions?: {
                url: string;
                total_count: number;
                "+1": number;
                "-1": number;
                laugh: number;
                confused: number;
                heart: number;
                hooray: number;
                eyes: number;
                rocket: number;
            } | undefined;
        }, 201>>;
        defaults: <O extends _octokit_types.RequestParameters = _octokit_types.RequestParameters>(newDefaults: O) => _octokit_types.RequestInterface<object & O>;
        endpoint: _octokit_types.EndpointInterface<{
            url: string;
        }>;
    }, any>;
    addIssueAssignees: (key: IntegrationTaskKey, params: {
        owner: string;
        repo: string;
        issueNumber: number;
        assignees: string[];
    }) => GitHubReturnType<{
        (params?: (_octokit_types.RequestParameters & Omit<{
            owner: string;
            repo: string;
            issue_number: number;
        } & {
            assignees?: string[] | undefined;
        }, "headers" | "baseUrl" | "mediaType">) | undefined): Promise<_octokit_types.OctokitResponse<{
            id: number;
            node_id: string;
            url: string;
            repository_url: string;
            labels_url: string;
            comments_url: string;
            events_url: string;
            html_url: string;
            number: number;
            state: string;
            state_reason?: "reopened" | "completed" | "not_planned" | null | undefined;
            title: string;
            body?: string | null | undefined;
            user: {
                name?: string | null | undefined;
                email?: string | null | undefined;
                login: string;
                id: number;
                node_id: string;
                avatar_url: string;
                gravatar_id: string | null;
                url: string;
                html_url: string;
                followers_url: string;
                following_url: string;
                gists_url: string;
                starred_url: string;
                subscriptions_url: string;
                organizations_url: string;
                repos_url: string;
                events_url: string;
                received_events_url: string;
                type: string;
                site_admin: boolean;
                starred_at?: string | undefined;
            } | null;
            labels: (string | {
                id?: number | undefined;
                node_id?: string | undefined;
                url?: string | undefined;
                name?: string | undefined;
                description?: string | null | undefined;
                color?: string | null | undefined;
                default?: boolean | undefined;
            })[];
            assignee: {
                name?: string | null | undefined;
                email?: string | null | undefined;
                login: string;
                id: number;
                node_id: string;
                avatar_url: string;
                gravatar_id: string | null;
                url: string;
                html_url: string;
                followers_url: string;
                following_url: string;
                gists_url: string;
                starred_url: string;
                subscriptions_url: string;
                organizations_url: string;
                repos_url: string;
                events_url: string;
                received_events_url: string;
                type: string;
                site_admin: boolean;
                starred_at?: string | undefined;
            } | null;
            assignees?: {
                name?: string | null | undefined;
                email?: string | null | undefined;
                login: string;
                id: number;
                node_id: string;
                avatar_url: string;
                gravatar_id: string | null;
                url: string;
                html_url: string;
                followers_url: string;
                following_url: string;
                gists_url: string;
                starred_url: string;
                subscriptions_url: string;
                organizations_url: string;
                repos_url: string;
                events_url: string;
                received_events_url: string;
                type: string;
                site_admin: boolean;
                starred_at?: string | undefined;
            }[] | null | undefined;
            milestone: {
                url: string;
                html_url: string;
                labels_url: string;
                id: number;
                node_id: string;
                number: number;
                state: "open" | "closed";
                title: string;
                description: string | null;
                creator: {
                    name?: string | null | undefined;
                    email?: string | null | undefined;
                    login: string;
                    id: number;
                    node_id: string;
                    avatar_url: string;
                    gravatar_id: string | null;
                    url: string;
                    html_url: string;
                    followers_url: string;
                    following_url: string;
                    gists_url: string;
                    starred_url: string;
                    subscriptions_url: string;
                    organizations_url: string;
                    repos_url: string;
                    events_url: string;
                    received_events_url: string;
                    type: string;
                    site_admin: boolean;
                    starred_at?: string | undefined;
                } | null;
                open_issues: number;
                closed_issues: number;
                created_at: string;
                updated_at: string;
                closed_at: string | null;
                due_on: string | null;
            } | null;
            locked: boolean;
            active_lock_reason?: string | null | undefined;
            comments: number;
            pull_request?: {
                merged_at?: string | null | undefined;
                diff_url: string | null;
                html_url: string | null;
                patch_url: string | null;
                url: string | null;
            } | undefined;
            closed_at: string | null;
            created_at: string;
            updated_at: string;
            draft?: boolean | undefined;
            closed_by?: {
                name?: string | null | undefined;
                email?: string | null | undefined;
                login: string;
                id: number;
                node_id: string;
                avatar_url: string;
                gravatar_id: string | null;
                url: string;
                html_url: string;
                followers_url: string;
                following_url: string;
                gists_url: string;
                starred_url: string;
                subscriptions_url: string;
                organizations_url: string;
                repos_url: string;
                events_url: string;
                received_events_url: string;
                type: string;
                site_admin: boolean;
                starred_at?: string | undefined;
            } | null | undefined;
            body_html?: string | undefined;
            body_text?: string | undefined;
            timeline_url?: string | undefined;
            repository?: {
                id: number;
                node_id: string;
                name: string;
                full_name: string;
                license: {
                    key: string;
                    name: string;
                    url: string | null;
                    spdx_id: string | null;
                    node_id: string;
                    html_url?: string | undefined;
                } | null;
                organization?: {
                    name?: string | null | undefined;
                    email?: string | null | undefined;
                    login: string;
                    id: number;
                    node_id: string;
                    avatar_url: string;
                    gravatar_id: string | null;
                    url: string;
                    html_url: string;
                    followers_url: string;
                    following_url: string;
                    gists_url: string;
                    starred_url: string;
                    subscriptions_url: string;
                    organizations_url: string;
                    repos_url: string;
                    events_url: string;
                    received_events_url: string;
                    type: string;
                    site_admin: boolean;
                    starred_at?: string | undefined;
                } | null | undefined;
                forks: number;
                permissions?: {
                    admin: boolean;
                    pull: boolean;
                    triage?: boolean | undefined;
                    push: boolean;
                    maintain?: boolean | undefined;
                } | undefined;
                owner: {
                    name?: string | null | undefined;
                    email?: string | null | undefined;
                    login: string;
                    id: number;
                    node_id: string;
                    avatar_url: string;
                    gravatar_id: string | null;
                    url: string;
                    html_url: string;
                    followers_url: string;
                    following_url: string;
                    gists_url: string;
                    starred_url: string;
                    subscriptions_url: string;
                    organizations_url: string;
                    repos_url: string;
                    events_url: string;
                    received_events_url: string;
                    type: string;
                    site_admin: boolean;
                    starred_at?: string | undefined;
                };
                private: boolean;
                html_url: string;
                description: string | null;
                fork: boolean;
                url: string;
                archive_url: string;
                assignees_url: string;
                blobs_url: string;
                branches_url: string;
                collaborators_url: string;
                comments_url: string;
                commits_url: string;
                compare_url: string;
                contents_url: string;
                contributors_url: string;
                deployments_url: string;
                downloads_url: string;
                events_url: string;
                forks_url: string;
                git_commits_url: string;
                git_refs_url: string;
                git_tags_url: string;
                git_url: string;
                issue_comment_url: string;
                issue_events_url: string;
                issues_url: string;
                keys_url: string;
                labels_url: string;
                languages_url: string;
                merges_url: string;
                milestones_url: string;
                notifications_url: string;
                pulls_url: string;
                releases_url: string;
                ssh_url: string;
                stargazers_url: string;
                statuses_url: string;
                subscribers_url: string;
                subscription_url: string;
                tags_url: string;
                teams_url: string;
                trees_url: string;
                clone_url: string;
                mirror_url: string | null;
                hooks_url: string;
                svn_url: string;
                homepage: string | null;
                language: string | null;
                forks_count: number;
                stargazers_count: number;
                watchers_count: number;
                size: number;
                default_branch: string;
                open_issues_count: number;
                is_template?: boolean | undefined;
                topics?: string[] | undefined;
                has_issues: boolean;
                has_projects: boolean;
                has_wiki: boolean;
                has_pages: boolean;
                has_downloads: boolean;
                has_discussions?: boolean | undefined;
                archived: boolean;
                disabled: boolean;
                visibility?: string | undefined;
                pushed_at: string | null;
                created_at: string | null;
                updated_at: string | null;
                allow_rebase_merge?: boolean | undefined;
                template_repository?: {
                    id?: number | undefined;
                    node_id?: string | undefined;
                    name?: string | undefined;
                    full_name?: string | undefined;
                    owner?: {
                        login?: string | undefined;
                        id?: number | undefined;
                        node_id?: string | undefined;
                        avatar_url?: string | undefined;
                        gravatar_id?: string | undefined;
                        url?: string | undefined;
                        html_url?: string | undefined;
                        followers_url?: string | undefined;
                        following_url?: string | undefined;
                        gists_url?: string | undefined;
                        starred_url?: string | undefined;
                        subscriptions_url?: string | undefined;
                        organizations_url?: string | undefined;
                        repos_url?: string | undefined;
                        events_url?: string | undefined;
                        received_events_url?: string | undefined;
                        type?: string | undefined;
                        site_admin?: boolean | undefined;
                    } | undefined;
                    private?: boolean | undefined;
                    html_url?: string | undefined;
                    description?: string | undefined;
                    fork?: boolean | undefined;
                    url?: string | undefined;
                    archive_url?: string | undefined;
                    assignees_url?: string | undefined;
                    blobs_url?: string | undefined;
                    branches_url?: string | undefined;
                    collaborators_url?: string | undefined;
                    comments_url?: string | undefined;
                    commits_url?: string | undefined;
                    compare_url?: string | undefined;
                    contents_url?: string | undefined;
                    contributors_url?: string | undefined;
                    deployments_url?: string | undefined;
                    downloads_url?: string | undefined;
                    events_url?: string | undefined;
                    forks_url?: string | undefined;
                    git_commits_url?: string | undefined;
                    git_refs_url?: string | undefined;
                    git_tags_url?: string | undefined;
                    git_url?: string | undefined;
                    issue_comment_url?: string | undefined;
                    issue_events_url?: string | undefined;
                    issues_url?: string | undefined;
                    keys_url?: string | undefined;
                    labels_url?: string | undefined;
                    languages_url?: string | undefined;
                    merges_url?: string | undefined;
                    milestones_url?: string | undefined;
                    notifications_url?: string | undefined;
                    pulls_url?: string | undefined;
                    releases_url?: string | undefined;
                    ssh_url?: string | undefined;
                    stargazers_url?: string | undefined;
                    statuses_url?: string | undefined;
                    subscribers_url?: string | undefined;
                    subscription_url?: string | undefined;
                    tags_url?: string | undefined;
                    teams_url?: string | undefined;
                    trees_url?: string | undefined;
                    clone_url?: string | undefined;
                    mirror_url?: string | undefined;
                    hooks_url?: string | undefined;
                    svn_url?: string | undefined;
                    homepage?: string | undefined;
                    language?: string | undefined;
                    forks_count?: number | undefined;
                    stargazers_count?: number | undefined;
                    watchers_count?: number | undefined;
                    size?: number | undefined;
                    default_branch?: string | undefined;
                    open_issues_count?: number | undefined;
                    is_template?: boolean | undefined;
                    topics?: string[] | undefined;
                    has_issues?: boolean | undefined;
                    has_projects?: boolean | undefined;
                    has_wiki?: boolean | undefined;
                    has_pages?: boolean | undefined;
                    has_downloads?: boolean | undefined;
                    archived?: boolean | undefined;
                    disabled?: boolean | undefined;
                    visibility?: string | undefined;
                    pushed_at?: string | undefined;
                    created_at?: string | undefined;
                    updated_at?: string | undefined;
                    permissions?: {
                        admin?: boolean | undefined;
                        maintain?: boolean | undefined;
                        push?: boolean | undefined;
                        triage?: boolean | undefined;
                        pull?: boolean | undefined;
                    } | undefined;
                    allow_rebase_merge?: boolean | undefined;
                    temp_clone_token?: string | undefined;
                    allow_squash_merge?: boolean | undefined;
                    allow_auto_merge?: boolean | undefined;
                    delete_branch_on_merge?: boolean | undefined;
                    allow_update_branch?: boolean | undefined;
                    use_squash_pr_title_as_default?: boolean | undefined;
                    squash_merge_commit_title?: "PR_TITLE" | "COMMIT_OR_PR_TITLE" | undefined;
                    squash_merge_commit_message?: "COMMIT_MESSAGES" | "PR_BODY" | "BLANK" | undefined;
                    merge_commit_title?: "MERGE_MESSAGE" | "PR_TITLE" | undefined;
                    merge_commit_message?: "PR_TITLE" | "PR_BODY" | "BLANK" | undefined;
                    allow_merge_commit?: boolean | undefined;
                    subscribers_count?: number | undefined;
                    network_count?: number | undefined;
                } | null | undefined;
                temp_clone_token?: string | undefined;
                allow_squash_merge?: boolean | undefined;
                allow_auto_merge?: boolean | undefined;
                delete_branch_on_merge?: boolean | undefined;
                allow_update_branch?: boolean | undefined;
                use_squash_pr_title_as_default?: boolean | undefined;
                squash_merge_commit_title?: "PR_TITLE" | "COMMIT_OR_PR_TITLE" | undefined;
                squash_merge_commit_message?: "COMMIT_MESSAGES" | "PR_BODY" | "BLANK" | undefined;
                merge_commit_title?: "MERGE_MESSAGE" | "PR_TITLE" | undefined;
                merge_commit_message?: "PR_TITLE" | "PR_BODY" | "BLANK" | undefined;
                allow_merge_commit?: boolean | undefined;
                allow_forking?: boolean | undefined;
                web_commit_signoff_required?: boolean | undefined;
                subscribers_count?: number | undefined;
                network_count?: number | undefined;
                open_issues: number;
                watchers: number;
                master_branch?: string | undefined;
                starred_at?: string | undefined;
                anonymous_access_enabled?: boolean | undefined;
            } | undefined;
            performed_via_github_app?: {
                id: number;
                slug?: string | undefined;
                node_id: string;
                owner: {
                    name?: string | null | undefined;
                    email?: string | null | undefined;
                    login: string;
                    id: number;
                    node_id: string;
                    avatar_url: string;
                    gravatar_id: string | null;
                    url: string;
                    html_url: string;
                    followers_url: string;
                    following_url: string;
                    gists_url: string;
                    starred_url: string;
                    subscriptions_url: string;
                    organizations_url: string;
                    repos_url: string;
                    events_url: string;
                    received_events_url: string;
                    type: string;
                    site_admin: boolean;
                    starred_at?: string | undefined;
                } | null;
                name: string;
                description: string | null;
                external_url: string;
                html_url: string;
                created_at: string;
                updated_at: string;
                permissions: {
                    [key: string]: string | undefined;
                    issues?: string | undefined;
                    checks?: string | undefined;
                    metadata?: string | undefined;
                    contents?: string | undefined;
                    deployments?: string | undefined;
                };
                events: string[];
                installations_count?: number | undefined;
                client_id?: string | undefined;
                client_secret?: string | undefined;
                webhook_secret?: string | null | undefined;
                pem?: string | undefined;
            } | null | undefined;
            author_association: "MEMBER" | "NONE" | "COLLABORATOR" | "CONTRIBUTOR" | "FIRST_TIMER" | "FIRST_TIME_CONTRIBUTOR" | "MANNEQUIN" | "OWNER";
            reactions?: {
                url: string;
                total_count: number;
                "+1": number;
                "-1": number;
                laugh: number;
                confused: number;
                heart: number;
                hooray: number;
                eyes: number;
                rocket: number;
            } | undefined;
        }, 201>>;
        defaults: <O extends _octokit_types.RequestParameters = _octokit_types.RequestParameters>(newDefaults: O) => _octokit_types.RequestInterface<object & O>;
        endpoint: _octokit_types.EndpointInterface<{
            url: string;
        }>;
    }, any>;
    addIssueLabels: (key: IntegrationTaskKey, params: {
        owner: string;
        repo: string;
        issueNumber: number;
        labels: string[];
    }) => Promise<{
        id: number;
        node_id: string;
        url: string;
        name: string;
        description: string | null;
        color: string;
        default: boolean;
    }[]>;
    createIssueComment: (key: IntegrationTaskKey, params: {
        body: string;
        owner: string;
        repo: string;
        issueNumber: number;
    }) => GitHubReturnType<{
        (params?: (_octokit_types.RequestParameters & Omit<{
            owner: string;
            repo: string;
            issue_number: number;
        } & {
            body: string;
        }, "headers" | "baseUrl" | "mediaType">) | undefined): Promise<_octokit_types.OctokitResponse<{
            id: number;
            node_id: string;
            url: string;
            body?: string | undefined;
            body_text?: string | undefined;
            body_html?: string | undefined;
            html_url: string;
            user: {
                name?: string | null | undefined;
                email?: string | null | undefined;
                login: string;
                id: number;
                node_id: string;
                avatar_url: string;
                gravatar_id: string | null;
                url: string;
                html_url: string;
                followers_url: string;
                following_url: string;
                gists_url: string;
                starred_url: string;
                subscriptions_url: string;
                organizations_url: string;
                repos_url: string;
                events_url: string;
                received_events_url: string;
                type: string;
                site_admin: boolean;
                starred_at?: string | undefined;
            } | null;
            created_at: string;
            updated_at: string;
            issue_url: string;
            author_association: "MEMBER" | "NONE" | "COLLABORATOR" | "CONTRIBUTOR" | "FIRST_TIMER" | "FIRST_TIME_CONTRIBUTOR" | "MANNEQUIN" | "OWNER";
            performed_via_github_app?: {
                id: number;
                slug?: string | undefined;
                node_id: string;
                owner: {
                    name?: string | null | undefined;
                    email?: string | null | undefined;
                    login: string;
                    id: number;
                    node_id: string;
                    avatar_url: string;
                    gravatar_id: string | null;
                    url: string;
                    html_url: string;
                    followers_url: string;
                    following_url: string;
                    gists_url: string;
                    starred_url: string;
                    subscriptions_url: string;
                    organizations_url: string;
                    repos_url: string;
                    events_url: string;
                    received_events_url: string;
                    type: string;
                    site_admin: boolean;
                    starred_at?: string | undefined;
                } | null;
                name: string;
                description: string | null;
                external_url: string;
                html_url: string;
                created_at: string;
                updated_at: string;
                permissions: {
                    [key: string]: string | undefined;
                    issues?: string | undefined;
                    checks?: string | undefined;
                    metadata?: string | undefined;
                    contents?: string | undefined;
                    deployments?: string | undefined;
                };
                events: string[];
                installations_count?: number | undefined;
                client_id?: string | undefined;
                client_secret?: string | undefined;
                webhook_secret?: string | null | undefined;
                pem?: string | undefined;
            } | null | undefined;
            reactions?: {
                url: string;
                total_count: number;
                "+1": number;
                "-1": number;
                laugh: number;
                confused: number;
                heart: number;
                hooray: number;
                eyes: number;
                rocket: number;
            } | undefined;
        }, 201>>;
        defaults: <O extends _octokit_types.RequestParameters = _octokit_types.RequestParameters>(newDefaults: O) => _octokit_types.RequestInterface<object & O>;
        endpoint: _octokit_types.EndpointInterface<{
            url: string;
        }>;
    }, any>;
    getIssue: (key: IntegrationTaskKey, params: {
        owner: string;
        repo: string;
        issueNumber: number;
    }) => GitHubReturnType<{
        (params?: (_octokit_types.RequestParameters & Omit<{
            owner: string;
            repo: string;
            issue_number: number;
        }, "headers" | "baseUrl" | "mediaType">) | undefined): Promise<_octokit_types.OctokitResponse<{
            id: number;
            node_id: string;
            url: string;
            repository_url: string;
            labels_url: string;
            comments_url: string;
            events_url: string;
            html_url: string;
            number: number;
            state: string;
            state_reason?: "reopened" | "completed" | "not_planned" | null | undefined;
            title: string;
            body?: string | null | undefined;
            user: {
                name?: string | null | undefined;
                email?: string | null | undefined;
                login: string;
                id: number;
                node_id: string;
                avatar_url: string;
                gravatar_id: string | null;
                url: string;
                html_url: string;
                followers_url: string;
                following_url: string;
                gists_url: string;
                starred_url: string;
                subscriptions_url: string;
                organizations_url: string;
                repos_url: string;
                events_url: string;
                received_events_url: string;
                type: string;
                site_admin: boolean;
                starred_at?: string | undefined;
            } | null;
            labels: (string | {
                id?: number | undefined;
                node_id?: string | undefined;
                url?: string | undefined;
                name?: string | undefined;
                description?: string | null | undefined;
                color?: string | null | undefined;
                default?: boolean | undefined;
            })[];
            assignee: {
                name?: string | null | undefined;
                email?: string | null | undefined;
                login: string;
                id: number;
                node_id: string;
                avatar_url: string;
                gravatar_id: string | null;
                url: string;
                html_url: string;
                followers_url: string;
                following_url: string;
                gists_url: string;
                starred_url: string;
                subscriptions_url: string;
                organizations_url: string;
                repos_url: string;
                events_url: string;
                received_events_url: string;
                type: string;
                site_admin: boolean;
                starred_at?: string | undefined;
            } | null;
            assignees?: {
                name?: string | null | undefined;
                email?: string | null | undefined;
                login: string;
                id: number;
                node_id: string;
                avatar_url: string;
                gravatar_id: string | null;
                url: string;
                html_url: string;
                followers_url: string;
                following_url: string;
                gists_url: string;
                starred_url: string;
                subscriptions_url: string;
                organizations_url: string;
                repos_url: string;
                events_url: string;
                received_events_url: string;
                type: string;
                site_admin: boolean;
                starred_at?: string | undefined;
            }[] | null | undefined;
            milestone: {
                url: string;
                html_url: string;
                labels_url: string;
                id: number;
                node_id: string;
                number: number;
                state: "open" | "closed";
                title: string;
                description: string | null;
                creator: {
                    name?: string | null | undefined;
                    email?: string | null | undefined;
                    login: string;
                    id: number;
                    node_id: string;
                    avatar_url: string;
                    gravatar_id: string | null;
                    url: string;
                    html_url: string;
                    followers_url: string;
                    following_url: string;
                    gists_url: string;
                    starred_url: string;
                    subscriptions_url: string;
                    organizations_url: string;
                    repos_url: string;
                    events_url: string;
                    received_events_url: string;
                    type: string;
                    site_admin: boolean;
                    starred_at?: string | undefined;
                } | null;
                open_issues: number;
                closed_issues: number;
                created_at: string;
                updated_at: string;
                closed_at: string | null;
                due_on: string | null;
            } | null;
            locked: boolean;
            active_lock_reason?: string | null | undefined;
            comments: number;
            pull_request?: {
                merged_at?: string | null | undefined;
                diff_url: string | null;
                html_url: string | null;
                patch_url: string | null;
                url: string | null;
            } | undefined;
            closed_at: string | null;
            created_at: string;
            updated_at: string;
            draft?: boolean | undefined;
            closed_by?: {
                name?: string | null | undefined;
                email?: string | null | undefined;
                login: string;
                id: number;
                node_id: string;
                avatar_url: string;
                gravatar_id: string | null;
                url: string;
                html_url: string;
                followers_url: string;
                following_url: string;
                gists_url: string;
                starred_url: string;
                subscriptions_url: string;
                organizations_url: string;
                repos_url: string;
                events_url: string;
                received_events_url: string;
                type: string;
                site_admin: boolean;
                starred_at?: string | undefined;
            } | null | undefined;
            body_html?: string | undefined;
            body_text?: string | undefined;
            timeline_url?: string | undefined;
            repository?: {
                id: number;
                node_id: string;
                name: string;
                full_name: string;
                license: {
                    key: string;
                    name: string;
                    url: string | null;
                    spdx_id: string | null;
                    node_id: string;
                    html_url?: string | undefined;
                } | null;
                organization?: {
                    name?: string | null | undefined;
                    email?: string | null | undefined;
                    login: string;
                    id: number;
                    node_id: string;
                    avatar_url: string;
                    gravatar_id: string | null;
                    url: string;
                    html_url: string;
                    followers_url: string;
                    following_url: string;
                    gists_url: string;
                    starred_url: string;
                    subscriptions_url: string;
                    organizations_url: string;
                    repos_url: string;
                    events_url: string;
                    received_events_url: string;
                    type: string;
                    site_admin: boolean;
                    starred_at?: string | undefined;
                } | null | undefined;
                forks: number;
                permissions?: {
                    admin: boolean;
                    pull: boolean;
                    triage?: boolean | undefined;
                    push: boolean;
                    maintain?: boolean | undefined;
                } | undefined;
                owner: {
                    name?: string | null | undefined;
                    email?: string | null | undefined;
                    login: string;
                    id: number;
                    node_id: string;
                    avatar_url: string;
                    gravatar_id: string | null;
                    url: string;
                    html_url: string;
                    followers_url: string;
                    following_url: string;
                    gists_url: string;
                    starred_url: string;
                    subscriptions_url: string;
                    organizations_url: string;
                    repos_url: string;
                    events_url: string;
                    received_events_url: string;
                    type: string;
                    site_admin: boolean;
                    starred_at?: string | undefined;
                };
                private: boolean;
                html_url: string;
                description: string | null;
                fork: boolean;
                url: string;
                archive_url: string;
                assignees_url: string;
                blobs_url: string;
                branches_url: string;
                collaborators_url: string;
                comments_url: string;
                commits_url: string;
                compare_url: string;
                contents_url: string;
                contributors_url: string;
                deployments_url: string;
                downloads_url: string;
                events_url: string;
                forks_url: string;
                git_commits_url: string;
                git_refs_url: string;
                git_tags_url: string;
                git_url: string;
                issue_comment_url: string;
                issue_events_url: string;
                issues_url: string;
                keys_url: string;
                labels_url: string;
                languages_url: string;
                merges_url: string;
                milestones_url: string;
                notifications_url: string;
                pulls_url: string;
                releases_url: string;
                ssh_url: string;
                stargazers_url: string;
                statuses_url: string;
                subscribers_url: string;
                subscription_url: string;
                tags_url: string;
                teams_url: string;
                trees_url: string;
                clone_url: string;
                mirror_url: string | null;
                hooks_url: string;
                svn_url: string;
                homepage: string | null;
                language: string | null;
                forks_count: number;
                stargazers_count: number;
                watchers_count: number;
                size: number;
                default_branch: string;
                open_issues_count: number;
                is_template?: boolean | undefined;
                topics?: string[] | undefined;
                has_issues: boolean;
                has_projects: boolean;
                has_wiki: boolean;
                has_pages: boolean;
                has_downloads: boolean;
                has_discussions?: boolean | undefined;
                archived: boolean;
                disabled: boolean;
                visibility?: string | undefined;
                pushed_at: string | null;
                created_at: string | null;
                updated_at: string | null;
                allow_rebase_merge?: boolean | undefined;
                template_repository?: {
                    id?: number | undefined;
                    node_id?: string | undefined;
                    name?: string | undefined;
                    full_name?: string | undefined;
                    owner?: {
                        login?: string | undefined;
                        id?: number | undefined;
                        node_id?: string | undefined;
                        avatar_url?: string | undefined;
                        gravatar_id?: string | undefined;
                        url?: string | undefined;
                        html_url?: string | undefined;
                        followers_url?: string | undefined;
                        following_url?: string | undefined;
                        gists_url?: string | undefined;
                        starred_url?: string | undefined;
                        subscriptions_url?: string | undefined;
                        organizations_url?: string | undefined;
                        repos_url?: string | undefined;
                        events_url?: string | undefined;
                        received_events_url?: string | undefined;
                        type?: string | undefined;
                        site_admin?: boolean | undefined;
                    } | undefined;
                    private?: boolean | undefined;
                    html_url?: string | undefined;
                    description?: string | undefined;
                    fork?: boolean | undefined;
                    url?: string | undefined;
                    archive_url?: string | undefined;
                    assignees_url?: string | undefined;
                    blobs_url?: string | undefined;
                    branches_url?: string | undefined;
                    collaborators_url?: string | undefined;
                    comments_url?: string | undefined;
                    commits_url?: string | undefined;
                    compare_url?: string | undefined;
                    contents_url?: string | undefined;
                    contributors_url?: string | undefined;
                    deployments_url?: string | undefined;
                    downloads_url?: string | undefined;
                    events_url?: string | undefined;
                    forks_url?: string | undefined;
                    git_commits_url?: string | undefined;
                    git_refs_url?: string | undefined;
                    git_tags_url?: string | undefined;
                    git_url?: string | undefined;
                    issue_comment_url?: string | undefined;
                    issue_events_url?: string | undefined;
                    issues_url?: string | undefined;
                    keys_url?: string | undefined;
                    labels_url?: string | undefined;
                    languages_url?: string | undefined;
                    merges_url?: string | undefined;
                    milestones_url?: string | undefined;
                    notifications_url?: string | undefined;
                    pulls_url?: string | undefined;
                    releases_url?: string | undefined;
                    ssh_url?: string | undefined;
                    stargazers_url?: string | undefined;
                    statuses_url?: string | undefined;
                    subscribers_url?: string | undefined;
                    subscription_url?: string | undefined;
                    tags_url?: string | undefined;
                    teams_url?: string | undefined;
                    trees_url?: string | undefined;
                    clone_url?: string | undefined;
                    mirror_url?: string | undefined;
                    hooks_url?: string | undefined;
                    svn_url?: string | undefined;
                    homepage?: string | undefined;
                    language?: string | undefined;
                    forks_count?: number | undefined;
                    stargazers_count?: number | undefined;
                    watchers_count?: number | undefined;
                    size?: number | undefined;
                    default_branch?: string | undefined;
                    open_issues_count?: number | undefined;
                    is_template?: boolean | undefined;
                    topics?: string[] | undefined;
                    has_issues?: boolean | undefined;
                    has_projects?: boolean | undefined;
                    has_wiki?: boolean | undefined;
                    has_pages?: boolean | undefined;
                    has_downloads?: boolean | undefined;
                    archived?: boolean | undefined;
                    disabled?: boolean | undefined;
                    visibility?: string | undefined;
                    pushed_at?: string | undefined;
                    created_at?: string | undefined;
                    updated_at?: string | undefined;
                    permissions?: {
                        admin?: boolean | undefined;
                        maintain?: boolean | undefined;
                        push?: boolean | undefined;
                        triage?: boolean | undefined;
                        pull?: boolean | undefined;
                    } | undefined;
                    allow_rebase_merge?: boolean | undefined;
                    temp_clone_token?: string | undefined;
                    allow_squash_merge?: boolean | undefined;
                    allow_auto_merge?: boolean | undefined;
                    delete_branch_on_merge?: boolean | undefined;
                    allow_update_branch?: boolean | undefined;
                    use_squash_pr_title_as_default?: boolean | undefined;
                    squash_merge_commit_title?: "PR_TITLE" | "COMMIT_OR_PR_TITLE" | undefined;
                    squash_merge_commit_message?: "COMMIT_MESSAGES" | "PR_BODY" | "BLANK" | undefined;
                    merge_commit_title?: "MERGE_MESSAGE" | "PR_TITLE" | undefined;
                    merge_commit_message?: "PR_TITLE" | "PR_BODY" | "BLANK" | undefined;
                    allow_merge_commit?: boolean | undefined;
                    subscribers_count?: number | undefined;
                    network_count?: number | undefined;
                } | null | undefined;
                temp_clone_token?: string | undefined;
                allow_squash_merge?: boolean | undefined;
                allow_auto_merge?: boolean | undefined;
                delete_branch_on_merge?: boolean | undefined;
                allow_update_branch?: boolean | undefined;
                use_squash_pr_title_as_default?: boolean | undefined;
                squash_merge_commit_title?: "PR_TITLE" | "COMMIT_OR_PR_TITLE" | undefined;
                squash_merge_commit_message?: "COMMIT_MESSAGES" | "PR_BODY" | "BLANK" | undefined;
                merge_commit_title?: "MERGE_MESSAGE" | "PR_TITLE" | undefined;
                merge_commit_message?: "PR_TITLE" | "PR_BODY" | "BLANK" | undefined;
                allow_merge_commit?: boolean | undefined;
                allow_forking?: boolean | undefined;
                web_commit_signoff_required?: boolean | undefined;
                subscribers_count?: number | undefined;
                network_count?: number | undefined;
                open_issues: number;
                watchers: number;
                master_branch?: string | undefined;
                starred_at?: string | undefined;
                anonymous_access_enabled?: boolean | undefined;
            } | undefined;
            performed_via_github_app?: {
                id: number;
                slug?: string | undefined;
                node_id: string;
                owner: {
                    name?: string | null | undefined;
                    email?: string | null | undefined;
                    login: string;
                    id: number;
                    node_id: string;
                    avatar_url: string;
                    gravatar_id: string | null;
                    url: string;
                    html_url: string;
                    followers_url: string;
                    following_url: string;
                    gists_url: string;
                    starred_url: string;
                    subscriptions_url: string;
                    organizations_url: string;
                    repos_url: string;
                    events_url: string;
                    received_events_url: string;
                    type: string;
                    site_admin: boolean;
                    starred_at?: string | undefined;
                } | null;
                name: string;
                description: string | null;
                external_url: string;
                html_url: string;
                created_at: string;
                updated_at: string;
                permissions: {
                    [key: string]: string | undefined;
                    issues?: string | undefined;
                    checks?: string | undefined;
                    metadata?: string | undefined;
                    contents?: string | undefined;
                    deployments?: string | undefined;
                };
                events: string[];
                installations_count?: number | undefined;
                client_id?: string | undefined;
                client_secret?: string | undefined;
                webhook_secret?: string | null | undefined;
                pem?: string | undefined;
            } | null | undefined;
            author_association: "MEMBER" | "NONE" | "COLLABORATOR" | "CONTRIBUTOR" | "FIRST_TIMER" | "FIRST_TIME_CONTRIBUTOR" | "MANNEQUIN" | "OWNER";
            reactions?: {
                url: string;
                total_count: number;
                "+1": number;
                "-1": number;
                laugh: number;
                confused: number;
                heart: number;
                hooray: number;
                eyes: number;
                rocket: number;
            } | undefined;
        }, 200>>;
        defaults: <O extends _octokit_types.RequestParameters = _octokit_types.RequestParameters>(newDefaults: O) => _octokit_types.RequestInterface<object & O>;
        endpoint: _octokit_types.EndpointInterface<{
            url: string;
        }>;
    }, any>;
    getRepo: (key: IntegrationTaskKey, params: {
        owner: string;
        repo: string;
    }) => GitHubReturnType<{
        (params?: (_octokit_types.RequestParameters & Omit<{
            owner: string;
            repo: string;
        }, "headers" | "baseUrl" | "mediaType">) | undefined): Promise<_octokit_types.OctokitResponse<{
            id: number;
            node_id: string;
            name: string;
            full_name: string;
            owner: {
                name?: string | null | undefined;
                email?: string | null | undefined;
                login: string;
                id: number;
                node_id: string;
                avatar_url: string;
                gravatar_id: string | null;
                url: string;
                html_url: string;
                followers_url: string;
                following_url: string;
                gists_url: string;
                starred_url: string;
                subscriptions_url: string;
                organizations_url: string;
                repos_url: string;
                events_url: string;
                received_events_url: string;
                type: string;
                site_admin: boolean;
                starred_at?: string | undefined;
            };
            private: boolean;
            html_url: string;
            description: string | null;
            fork: boolean;
            url: string;
            archive_url: string;
            assignees_url: string;
            blobs_url: string;
            branches_url: string;
            collaborators_url: string;
            comments_url: string;
            commits_url: string;
            compare_url: string;
            contents_url: string;
            contributors_url: string;
            deployments_url: string;
            downloads_url: string;
            events_url: string;
            forks_url: string;
            git_commits_url: string;
            git_refs_url: string;
            git_tags_url: string;
            git_url: string;
            issue_comment_url: string;
            issue_events_url: string;
            issues_url: string;
            keys_url: string;
            labels_url: string;
            languages_url: string;
            merges_url: string;
            milestones_url: string;
            notifications_url: string;
            pulls_url: string;
            releases_url: string;
            ssh_url: string;
            stargazers_url: string;
            statuses_url: string;
            subscribers_url: string;
            subscription_url: string;
            tags_url: string;
            teams_url: string;
            trees_url: string;
            clone_url: string;
            mirror_url: string | null;
            hooks_url: string;
            svn_url: string;
            homepage: string | null;
            language: string | null;
            forks_count: number;
            stargazers_count: number;
            watchers_count: number;
            size: number;
            default_branch: string;
            open_issues_count: number;
            is_template?: boolean | undefined;
            topics?: string[] | undefined;
            has_issues: boolean;
            has_projects: boolean;
            has_wiki: boolean;
            has_pages: boolean;
            has_downloads: boolean;
            has_discussions: boolean;
            archived: boolean;
            disabled: boolean;
            visibility?: string | undefined;
            pushed_at: string;
            created_at: string;
            updated_at: string;
            permissions?: {
                admin: boolean;
                maintain?: boolean | undefined;
                push: boolean;
                triage?: boolean | undefined;
                pull: boolean;
            } | undefined;
            allow_rebase_merge?: boolean | undefined;
            template_repository?: {
                id: number;
                node_id: string;
                name: string;
                full_name: string;
                license: {
                    key: string;
                    name: string;
                    url: string | null;
                    spdx_id: string | null;
                    node_id: string;
                    html_url?: string | undefined;
                } | null;
                organization?: {
                    name?: string | null | undefined;
                    email?: string | null | undefined;
                    login: string;
                    id: number;
                    node_id: string;
                    avatar_url: string;
                    gravatar_id: string | null;
                    url: string;
                    html_url: string;
                    followers_url: string;
                    following_url: string;
                    gists_url: string;
                    starred_url: string;
                    subscriptions_url: string;
                    organizations_url: string;
                    repos_url: string;
                    events_url: string;
                    received_events_url: string;
                    type: string;
                    site_admin: boolean;
                    starred_at?: string | undefined;
                } | null | undefined;
                forks: number;
                permissions?: {
                    admin: boolean;
                    pull: boolean;
                    triage?: boolean | undefined;
                    push: boolean;
                    maintain?: boolean | undefined;
                } | undefined;
                owner: {
                    name?: string | null | undefined;
                    email?: string | null | undefined;
                    login: string;
                    id: number;
                    node_id: string;
                    avatar_url: string;
                    gravatar_id: string | null;
                    url: string;
                    html_url: string;
                    followers_url: string;
                    following_url: string;
                    gists_url: string;
                    starred_url: string;
                    subscriptions_url: string;
                    organizations_url: string;
                    repos_url: string;
                    events_url: string;
                    received_events_url: string;
                    type: string;
                    site_admin: boolean;
                    starred_at?: string | undefined;
                };
                private: boolean;
                html_url: string;
                description: string | null;
                fork: boolean;
                url: string;
                archive_url: string;
                assignees_url: string;
                blobs_url: string;
                branches_url: string;
                collaborators_url: string;
                comments_url: string;
                commits_url: string;
                compare_url: string;
                contents_url: string;
                contributors_url: string;
                deployments_url: string;
                downloads_url: string;
                events_url: string;
                forks_url: string;
                git_commits_url: string;
                git_refs_url: string;
                git_tags_url: string;
                git_url: string;
                issue_comment_url: string;
                issue_events_url: string;
                issues_url: string;
                keys_url: string;
                labels_url: string;
                languages_url: string;
                merges_url: string;
                milestones_url: string;
                notifications_url: string;
                pulls_url: string;
                releases_url: string;
                ssh_url: string;
                stargazers_url: string;
                statuses_url: string;
                subscribers_url: string;
                subscription_url: string;
                tags_url: string;
                teams_url: string;
                trees_url: string;
                clone_url: string;
                mirror_url: string | null;
                hooks_url: string;
                svn_url: string;
                homepage: string | null;
                language: string | null;
                forks_count: number;
                stargazers_count: number;
                watchers_count: number;
                size: number;
                default_branch: string;
                open_issues_count: number;
                is_template?: boolean | undefined;
                topics?: string[] | undefined;
                has_issues: boolean;
                has_projects: boolean;
                has_wiki: boolean;
                has_pages: boolean;
                has_downloads: boolean;
                has_discussions?: boolean | undefined;
                archived: boolean;
                disabled: boolean;
                visibility?: string | undefined;
                pushed_at: string | null;
                created_at: string | null;
                updated_at: string | null;
                allow_rebase_merge?: boolean | undefined;
                template_repository?: {
                    id?: number | undefined;
                    node_id?: string | undefined;
                    name?: string | undefined;
                    full_name?: string | undefined;
                    owner?: {
                        login?: string | undefined;
                        id?: number | undefined;
                        node_id?: string | undefined;
                        avatar_url?: string | undefined;
                        gravatar_id?: string | undefined;
                        url?: string | undefined;
                        html_url?: string | undefined;
                        followers_url?: string | undefined;
                        following_url?: string | undefined;
                        gists_url?: string | undefined;
                        starred_url?: string | undefined;
                        subscriptions_url?: string | undefined;
                        organizations_url?: string | undefined;
                        repos_url?: string | undefined;
                        events_url?: string | undefined;
                        received_events_url?: string | undefined;
                        type?: string | undefined;
                        site_admin?: boolean | undefined;
                    } | undefined;
                    private?: boolean | undefined;
                    html_url?: string | undefined;
                    description?: string | undefined;
                    fork?: boolean | undefined;
                    url?: string | undefined;
                    archive_url?: string | undefined;
                    assignees_url?: string | undefined;
                    blobs_url?: string | undefined;
                    branches_url?: string | undefined;
                    collaborators_url?: string | undefined;
                    comments_url?: string | undefined;
                    commits_url?: string | undefined;
                    compare_url?: string | undefined;
                    contents_url?: string | undefined;
                    contributors_url?: string | undefined;
                    deployments_url?: string | undefined;
                    downloads_url?: string | undefined;
                    events_url?: string | undefined;
                    forks_url?: string | undefined;
                    git_commits_url?: string | undefined;
                    git_refs_url?: string | undefined;
                    git_tags_url?: string | undefined;
                    git_url?: string | undefined;
                    issue_comment_url?: string | undefined;
                    issue_events_url?: string | undefined;
                    issues_url?: string | undefined;
                    keys_url?: string | undefined;
                    labels_url?: string | undefined;
                    languages_url?: string | undefined;
                    merges_url?: string | undefined;
                    milestones_url?: string | undefined;
                    notifications_url?: string | undefined;
                    pulls_url?: string | undefined;
                    releases_url?: string | undefined;
                    ssh_url?: string | undefined;
                    stargazers_url?: string | undefined;
                    statuses_url?: string | undefined;
                    subscribers_url?: string | undefined;
                    subscription_url?: string | undefined;
                    tags_url?: string | undefined;
                    teams_url?: string | undefined;
                    trees_url?: string | undefined;
                    clone_url?: string | undefined;
                    mirror_url?: string | undefined;
                    hooks_url?: string | undefined;
                    svn_url?: string | undefined;
                    homepage?: string | undefined;
                    language?: string | undefined;
                    forks_count?: number | undefined;
                    stargazers_count?: number | undefined;
                    watchers_count?: number | undefined;
                    size?: number | undefined;
                    default_branch?: string | undefined;
                    open_issues_count?: number | undefined;
                    is_template?: boolean | undefined;
                    topics?: string[] | undefined;
                    has_issues?: boolean | undefined;
                    has_projects?: boolean | undefined;
                    has_wiki?: boolean | undefined;
                    has_pages?: boolean | undefined;
                    has_downloads?: boolean | undefined;
                    archived?: boolean | undefined;
                    disabled?: boolean | undefined;
                    visibility?: string | undefined;
                    pushed_at?: string | undefined;
                    created_at?: string | undefined;
                    updated_at?: string | undefined;
                    permissions?: {
                        admin?: boolean | undefined;
                        maintain?: boolean | undefined;
                        push?: boolean | undefined;
                        triage?: boolean | undefined;
                        pull?: boolean | undefined;
                    } | undefined;
                    allow_rebase_merge?: boolean | undefined;
                    temp_clone_token?: string | undefined;
                    allow_squash_merge?: boolean | undefined;
                    allow_auto_merge?: boolean | undefined;
                    delete_branch_on_merge?: boolean | undefined;
                    allow_update_branch?: boolean | undefined;
                    use_squash_pr_title_as_default?: boolean | undefined;
                    squash_merge_commit_title?: "PR_TITLE" | "COMMIT_OR_PR_TITLE" | undefined;
                    squash_merge_commit_message?: "COMMIT_MESSAGES" | "PR_BODY" | "BLANK" | undefined;
                    merge_commit_title?: "MERGE_MESSAGE" | "PR_TITLE" | undefined;
                    merge_commit_message?: "PR_TITLE" | "PR_BODY" | "BLANK" | undefined;
                    allow_merge_commit?: boolean | undefined;
                    subscribers_count?: number | undefined;
                    network_count?: number | undefined;
                } | null | undefined;
                temp_clone_token?: string | undefined;
                allow_squash_merge?: boolean | undefined;
                allow_auto_merge?: boolean | undefined;
                delete_branch_on_merge?: boolean | undefined;
                allow_update_branch?: boolean | undefined;
                use_squash_pr_title_as_default?: boolean | undefined;
                squash_merge_commit_title?: "PR_TITLE" | "COMMIT_OR_PR_TITLE" | undefined;
                squash_merge_commit_message?: "COMMIT_MESSAGES" | "PR_BODY" | "BLANK" | undefined;
                merge_commit_title?: "MERGE_MESSAGE" | "PR_TITLE" | undefined;
                merge_commit_message?: "PR_TITLE" | "PR_BODY" | "BLANK" | undefined;
                allow_merge_commit?: boolean | undefined;
                allow_forking?: boolean | undefined;
                web_commit_signoff_required?: boolean | undefined;
                subscribers_count?: number | undefined;
                network_count?: number | undefined;
                open_issues: number;
                watchers: number;
                master_branch?: string | undefined;
                starred_at?: string | undefined;
                anonymous_access_enabled?: boolean | undefined;
            } | null | undefined;
            temp_clone_token?: string | null | undefined;
            allow_squash_merge?: boolean | undefined;
            allow_auto_merge?: boolean | undefined;
            delete_branch_on_merge?: boolean | undefined;
            allow_merge_commit?: boolean | undefined;
            allow_update_branch?: boolean | undefined;
            use_squash_pr_title_as_default?: boolean | undefined;
            squash_merge_commit_title?: "PR_TITLE" | "COMMIT_OR_PR_TITLE" | undefined;
            squash_merge_commit_message?: "COMMIT_MESSAGES" | "PR_BODY" | "BLANK" | undefined;
            merge_commit_title?: "MERGE_MESSAGE" | "PR_TITLE" | undefined;
            merge_commit_message?: "PR_TITLE" | "PR_BODY" | "BLANK" | undefined;
            allow_forking?: boolean | undefined;
            web_commit_signoff_required?: boolean | undefined;
            subscribers_count: number;
            network_count: number;
            license: {
                key: string;
                name: string;
                url: string | null;
                spdx_id: string | null;
                node_id: string;
                html_url?: string | undefined;
            } | null;
            organization?: {
                name?: string | null | undefined;
                email?: string | null | undefined;
                login: string;
                id: number;
                node_id: string;
                avatar_url: string;
                gravatar_id: string | null;
                url: string;
                html_url: string;
                followers_url: string;
                following_url: string;
                gists_url: string;
                starred_url: string;
                subscriptions_url: string;
                organizations_url: string;
                repos_url: string;
                events_url: string;
                received_events_url: string;
                type: string;
                site_admin: boolean;
                starred_at?: string | undefined;
            } | null | undefined;
            parent?: {
                id: number;
                node_id: string;
                name: string;
                full_name: string;
                license: {
                    key: string;
                    name: string;
                    url: string | null;
                    spdx_id: string | null;
                    node_id: string;
                    html_url?: string | undefined;
                } | null;
                organization?: {
                    name?: string | null | undefined;
                    email?: string | null | undefined;
                    login: string;
                    id: number;
                    node_id: string;
                    avatar_url: string;
                    gravatar_id: string | null;
                    url: string;
                    html_url: string;
                    followers_url: string;
                    following_url: string;
                    gists_url: string;
                    starred_url: string;
                    subscriptions_url: string;
                    organizations_url: string;
                    repos_url: string;
                    events_url: string;
                    received_events_url: string;
                    type: string;
                    site_admin: boolean;
                    starred_at?: string | undefined;
                } | null | undefined;
                forks: number;
                permissions?: {
                    admin: boolean;
                    pull: boolean;
                    triage?: boolean | undefined;
                    push: boolean;
                    maintain?: boolean | undefined;
                } | undefined;
                owner: {
                    name?: string | null | undefined;
                    email?: string | null | undefined;
                    login: string;
                    id: number;
                    node_id: string;
                    avatar_url: string;
                    gravatar_id: string | null;
                    url: string;
                    html_url: string;
                    followers_url: string;
                    following_url: string;
                    gists_url: string;
                    starred_url: string;
                    subscriptions_url: string;
                    organizations_url: string;
                    repos_url: string;
                    events_url: string;
                    received_events_url: string;
                    type: string;
                    site_admin: boolean;
                    starred_at?: string | undefined;
                };
                private: boolean;
                html_url: string;
                description: string | null;
                fork: boolean;
                url: string;
                archive_url: string;
                assignees_url: string;
                blobs_url: string;
                branches_url: string;
                collaborators_url: string;
                comments_url: string;
                commits_url: string;
                compare_url: string;
                contents_url: string;
                contributors_url: string;
                deployments_url: string;
                downloads_url: string;
                events_url: string;
                forks_url: string;
                git_commits_url: string;
                git_refs_url: string;
                git_tags_url: string;
                git_url: string;
                issue_comment_url: string;
                issue_events_url: string;
                issues_url: string;
                keys_url: string;
                labels_url: string;
                languages_url: string;
                merges_url: string;
                milestones_url: string;
                notifications_url: string;
                pulls_url: string;
                releases_url: string;
                ssh_url: string;
                stargazers_url: string;
                statuses_url: string;
                subscribers_url: string;
                subscription_url: string;
                tags_url: string;
                teams_url: string;
                trees_url: string;
                clone_url: string;
                mirror_url: string | null;
                hooks_url: string;
                svn_url: string;
                homepage: string | null;
                language: string | null;
                forks_count: number;
                stargazers_count: number;
                watchers_count: number;
                size: number;
                default_branch: string;
                open_issues_count: number;
                is_template?: boolean | undefined;
                topics?: string[] | undefined;
                has_issues: boolean;
                has_projects: boolean;
                has_wiki: boolean;
                has_pages: boolean;
                has_downloads: boolean;
                has_discussions?: boolean | undefined;
                archived: boolean;
                disabled: boolean;
                visibility?: string | undefined;
                pushed_at: string | null;
                created_at: string | null;
                updated_at: string | null;
                allow_rebase_merge?: boolean | undefined;
                template_repository?: {
                    id?: number | undefined;
                    node_id?: string | undefined;
                    name?: string | undefined;
                    full_name?: string | undefined;
                    owner?: {
                        login?: string | undefined;
                        id?: number | undefined;
                        node_id?: string | undefined;
                        avatar_url?: string | undefined;
                        gravatar_id?: string | undefined;
                        url?: string | undefined;
                        html_url?: string | undefined;
                        followers_url?: string | undefined;
                        following_url?: string | undefined;
                        gists_url?: string | undefined;
                        starred_url?: string | undefined;
                        subscriptions_url?: string | undefined;
                        organizations_url?: string | undefined;
                        repos_url?: string | undefined;
                        events_url?: string | undefined;
                        received_events_url?: string | undefined;
                        type?: string | undefined;
                        site_admin?: boolean | undefined;
                    } | undefined;
                    private?: boolean | undefined;
                    html_url?: string | undefined;
                    description?: string | undefined;
                    fork?: boolean | undefined;
                    url?: string | undefined;
                    archive_url?: string | undefined;
                    assignees_url?: string | undefined;
                    blobs_url?: string | undefined;
                    branches_url?: string | undefined;
                    collaborators_url?: string | undefined;
                    comments_url?: string | undefined;
                    commits_url?: string | undefined;
                    compare_url?: string | undefined;
                    contents_url?: string | undefined;
                    contributors_url?: string | undefined;
                    deployments_url?: string | undefined;
                    downloads_url?: string | undefined;
                    events_url?: string | undefined;
                    forks_url?: string | undefined;
                    git_commits_url?: string | undefined;
                    git_refs_url?: string | undefined;
                    git_tags_url?: string | undefined;
                    git_url?: string | undefined;
                    issue_comment_url?: string | undefined;
                    issue_events_url?: string | undefined;
                    issues_url?: string | undefined;
                    keys_url?: string | undefined;
                    labels_url?: string | undefined;
                    languages_url?: string | undefined;
                    merges_url?: string | undefined;
                    milestones_url?: string | undefined;
                    notifications_url?: string | undefined;
                    pulls_url?: string | undefined;
                    releases_url?: string | undefined;
                    ssh_url?: string | undefined;
                    stargazers_url?: string | undefined;
                    statuses_url?: string | undefined;
                    subscribers_url?: string | undefined;
                    subscription_url?: string | undefined;
                    tags_url?: string | undefined;
                    teams_url?: string | undefined;
                    trees_url?: string | undefined;
                    clone_url?: string | undefined;
                    mirror_url?: string | undefined;
                    hooks_url?: string | undefined;
                    svn_url?: string | undefined;
                    homepage?: string | undefined;
                    language?: string | undefined;
                    forks_count?: number | undefined;
                    stargazers_count?: number | undefined;
                    watchers_count?: number | undefined;
                    size?: number | undefined;
                    default_branch?: string | undefined;
                    open_issues_count?: number | undefined;
                    is_template?: boolean | undefined;
                    topics?: string[] | undefined;
                    has_issues?: boolean | undefined;
                    has_projects?: boolean | undefined;
                    has_wiki?: boolean | undefined;
                    has_pages?: boolean | undefined;
                    has_downloads?: boolean | undefined;
                    archived?: boolean | undefined;
                    disabled?: boolean | undefined;
                    visibility?: string | undefined;
                    pushed_at?: string | undefined;
                    created_at?: string | undefined;
                    updated_at?: string | undefined;
                    permissions?: {
                        admin?: boolean | undefined;
                        maintain?: boolean | undefined;
                        push?: boolean | undefined;
                        triage?: boolean | undefined;
                        pull?: boolean | undefined;
                    } | undefined;
                    allow_rebase_merge?: boolean | undefined;
                    temp_clone_token?: string | undefined;
                    allow_squash_merge?: boolean | undefined;
                    allow_auto_merge?: boolean | undefined;
                    delete_branch_on_merge?: boolean | undefined;
                    allow_update_branch?: boolean | undefined;
                    use_squash_pr_title_as_default?: boolean | undefined;
                    squash_merge_commit_title?: "PR_TITLE" | "COMMIT_OR_PR_TITLE" | undefined;
                    squash_merge_commit_message?: "COMMIT_MESSAGES" | "PR_BODY" | "BLANK" | undefined;
                    merge_commit_title?: "MERGE_MESSAGE" | "PR_TITLE" | undefined;
                    merge_commit_message?: "PR_TITLE" | "PR_BODY" | "BLANK" | undefined;
                    allow_merge_commit?: boolean | undefined;
                    subscribers_count?: number | undefined;
                    network_count?: number | undefined;
                } | null | undefined;
                temp_clone_token?: string | undefined;
                allow_squash_merge?: boolean | undefined;
                allow_auto_merge?: boolean | undefined;
                delete_branch_on_merge?: boolean | undefined;
                allow_update_branch?: boolean | undefined;
                use_squash_pr_title_as_default?: boolean | undefined;
                squash_merge_commit_title?: "PR_TITLE" | "COMMIT_OR_PR_TITLE" | undefined;
                squash_merge_commit_message?: "COMMIT_MESSAGES" | "PR_BODY" | "BLANK" | undefined;
                merge_commit_title?: "MERGE_MESSAGE" | "PR_TITLE" | undefined;
                merge_commit_message?: "PR_TITLE" | "PR_BODY" | "BLANK" | undefined;
                allow_merge_commit?: boolean | undefined;
                allow_forking?: boolean | undefined;
                web_commit_signoff_required?: boolean | undefined;
                subscribers_count?: number | undefined;
                network_count?: number | undefined;
                open_issues: number;
                watchers: number;
                master_branch?: string | undefined;
                starred_at?: string | undefined;
                anonymous_access_enabled?: boolean | undefined;
            } | undefined;
            source?: {
                id: number;
                node_id: string;
                name: string;
                full_name: string;
                license: {
                    key: string;
                    name: string;
                    url: string | null;
                    spdx_id: string | null;
                    node_id: string;
                    html_url?: string | undefined;
                } | null;
                organization?: {
                    name?: string | null | undefined;
                    email?: string | null | undefined;
                    login: string;
                    id: number;
                    node_id: string;
                    avatar_url: string;
                    gravatar_id: string | null;
                    url: string;
                    html_url: string;
                    followers_url: string;
                    following_url: string;
                    gists_url: string;
                    starred_url: string;
                    subscriptions_url: string;
                    organizations_url: string;
                    repos_url: string;
                    events_url: string;
                    received_events_url: string;
                    type: string;
                    site_admin: boolean;
                    starred_at?: string | undefined;
                } | null | undefined;
                forks: number;
                permissions?: {
                    admin: boolean;
                    pull: boolean;
                    triage?: boolean | undefined;
                    push: boolean;
                    maintain?: boolean | undefined;
                } | undefined;
                owner: {
                    name?: string | null | undefined;
                    email?: string | null | undefined;
                    login: string;
                    id: number;
                    node_id: string;
                    avatar_url: string;
                    gravatar_id: string | null;
                    url: string;
                    html_url: string;
                    followers_url: string;
                    following_url: string;
                    gists_url: string;
                    starred_url: string;
                    subscriptions_url: string;
                    organizations_url: string;
                    repos_url: string;
                    events_url: string;
                    received_events_url: string;
                    type: string;
                    site_admin: boolean;
                    starred_at?: string | undefined;
                };
                private: boolean;
                html_url: string;
                description: string | null;
                fork: boolean;
                url: string;
                archive_url: string;
                assignees_url: string;
                blobs_url: string;
                branches_url: string;
                collaborators_url: string;
                comments_url: string;
                commits_url: string;
                compare_url: string;
                contents_url: string;
                contributors_url: string;
                deployments_url: string;
                downloads_url: string;
                events_url: string;
                forks_url: string;
                git_commits_url: string;
                git_refs_url: string;
                git_tags_url: string;
                git_url: string;
                issue_comment_url: string;
                issue_events_url: string;
                issues_url: string;
                keys_url: string;
                labels_url: string;
                languages_url: string;
                merges_url: string;
                milestones_url: string;
                notifications_url: string;
                pulls_url: string;
                releases_url: string;
                ssh_url: string;
                stargazers_url: string;
                statuses_url: string;
                subscribers_url: string;
                subscription_url: string;
                tags_url: string;
                teams_url: string;
                trees_url: string;
                clone_url: string;
                mirror_url: string | null;
                hooks_url: string;
                svn_url: string;
                homepage: string | null;
                language: string | null;
                forks_count: number;
                stargazers_count: number;
                watchers_count: number;
                size: number;
                default_branch: string;
                open_issues_count: number;
                is_template?: boolean | undefined;
                topics?: string[] | undefined;
                has_issues: boolean;
                has_projects: boolean;
                has_wiki: boolean;
                has_pages: boolean;
                has_downloads: boolean;
                has_discussions?: boolean | undefined;
                archived: boolean;
                disabled: boolean;
                visibility?: string | undefined;
                pushed_at: string | null;
                created_at: string | null;
                updated_at: string | null;
                allow_rebase_merge?: boolean | undefined;
                template_repository?: {
                    id?: number | undefined;
                    node_id?: string | undefined;
                    name?: string | undefined;
                    full_name?: string | undefined;
                    owner?: {
                        login?: string | undefined;
                        id?: number | undefined;
                        node_id?: string | undefined;
                        avatar_url?: string | undefined;
                        gravatar_id?: string | undefined;
                        url?: string | undefined;
                        html_url?: string | undefined;
                        followers_url?: string | undefined;
                        following_url?: string | undefined;
                        gists_url?: string | undefined;
                        starred_url?: string | undefined;
                        subscriptions_url?: string | undefined;
                        organizations_url?: string | undefined;
                        repos_url?: string | undefined;
                        events_url?: string | undefined;
                        received_events_url?: string | undefined;
                        type?: string | undefined;
                        site_admin?: boolean | undefined;
                    } | undefined;
                    private?: boolean | undefined;
                    html_url?: string | undefined;
                    description?: string | undefined;
                    fork?: boolean | undefined;
                    url?: string | undefined;
                    archive_url?: string | undefined;
                    assignees_url?: string | undefined;
                    blobs_url?: string | undefined;
                    branches_url?: string | undefined;
                    collaborators_url?: string | undefined;
                    comments_url?: string | undefined;
                    commits_url?: string | undefined;
                    compare_url?: string | undefined;
                    contents_url?: string | undefined;
                    contributors_url?: string | undefined;
                    deployments_url?: string | undefined;
                    downloads_url?: string | undefined;
                    events_url?: string | undefined;
                    forks_url?: string | undefined;
                    git_commits_url?: string | undefined;
                    git_refs_url?: string | undefined;
                    git_tags_url?: string | undefined;
                    git_url?: string | undefined;
                    issue_comment_url?: string | undefined;
                    issue_events_url?: string | undefined;
                    issues_url?: string | undefined;
                    keys_url?: string | undefined;
                    labels_url?: string | undefined;
                    languages_url?: string | undefined;
                    merges_url?: string | undefined;
                    milestones_url?: string | undefined;
                    notifications_url?: string | undefined;
                    pulls_url?: string | undefined;
                    releases_url?: string | undefined;
                    ssh_url?: string | undefined;
                    stargazers_url?: string | undefined;
                    statuses_url?: string | undefined;
                    subscribers_url?: string | undefined;
                    subscription_url?: string | undefined;
                    tags_url?: string | undefined;
                    teams_url?: string | undefined;
                    trees_url?: string | undefined;
                    clone_url?: string | undefined;
                    mirror_url?: string | undefined;
                    hooks_url?: string | undefined;
                    svn_url?: string | undefined;
                    homepage?: string | undefined;
                    language?: string | undefined;
                    forks_count?: number | undefined;
                    stargazers_count?: number | undefined;
                    watchers_count?: number | undefined;
                    size?: number | undefined;
                    default_branch?: string | undefined;
                    open_issues_count?: number | undefined;
                    is_template?: boolean | undefined;
                    topics?: string[] | undefined;
                    has_issues?: boolean | undefined;
                    has_projects?: boolean | undefined;
                    has_wiki?: boolean | undefined;
                    has_pages?: boolean | undefined;
                    has_downloads?: boolean | undefined;
                    archived?: boolean | undefined;
                    disabled?: boolean | undefined;
                    visibility?: string | undefined;
                    pushed_at?: string | undefined;
                    created_at?: string | undefined;
                    updated_at?: string | undefined;
                    permissions?: {
                        admin?: boolean | undefined;
                        maintain?: boolean | undefined;
                        push?: boolean | undefined;
                        triage?: boolean | undefined;
                        pull?: boolean | undefined;
                    } | undefined;
                    allow_rebase_merge?: boolean | undefined;
                    temp_clone_token?: string | undefined;
                    allow_squash_merge?: boolean | undefined;
                    allow_auto_merge?: boolean | undefined;
                    delete_branch_on_merge?: boolean | undefined;
                    allow_update_branch?: boolean | undefined;
                    use_squash_pr_title_as_default?: boolean | undefined;
                    squash_merge_commit_title?: "PR_TITLE" | "COMMIT_OR_PR_TITLE" | undefined;
                    squash_merge_commit_message?: "COMMIT_MESSAGES" | "PR_BODY" | "BLANK" | undefined;
                    merge_commit_title?: "MERGE_MESSAGE" | "PR_TITLE" | undefined;
                    merge_commit_message?: "PR_TITLE" | "PR_BODY" | "BLANK" | undefined;
                    allow_merge_commit?: boolean | undefined;
                    subscribers_count?: number | undefined;
                    network_count?: number | undefined;
                } | null | undefined;
                temp_clone_token?: string | undefined;
                allow_squash_merge?: boolean | undefined;
                allow_auto_merge?: boolean | undefined;
                delete_branch_on_merge?: boolean | undefined;
                allow_update_branch?: boolean | undefined;
                use_squash_pr_title_as_default?: boolean | undefined;
                squash_merge_commit_title?: "PR_TITLE" | "COMMIT_OR_PR_TITLE" | undefined;
                squash_merge_commit_message?: "COMMIT_MESSAGES" | "PR_BODY" | "BLANK" | undefined;
                merge_commit_title?: "MERGE_MESSAGE" | "PR_TITLE" | undefined;
                merge_commit_message?: "PR_TITLE" | "PR_BODY" | "BLANK" | undefined;
                allow_merge_commit?: boolean | undefined;
                allow_forking?: boolean | undefined;
                web_commit_signoff_required?: boolean | undefined;
                subscribers_count?: number | undefined;
                network_count?: number | undefined;
                open_issues: number;
                watchers: number;
                master_branch?: string | undefined;
                starred_at?: string | undefined;
                anonymous_access_enabled?: boolean | undefined;
            } | undefined;
            forks: number;
            master_branch?: string | undefined;
            open_issues: number;
            watchers: number;
            anonymous_access_enabled?: boolean | undefined;
            code_of_conduct?: {
                url: string;
                key: string;
                name: string;
                html_url: string | null;
            } | undefined;
            security_and_analysis?: {
                advanced_security?: {
                    status?: "enabled" | "disabled" | undefined;
                } | undefined;
                secret_scanning?: {
                    status?: "enabled" | "disabled" | undefined;
                } | undefined;
                secret_scanning_push_protection?: {
                    status?: "enabled" | "disabled" | undefined;
                } | undefined;
            } | null | undefined;
        }, 200>>;
        defaults: <O extends _octokit_types.RequestParameters = _octokit_types.RequestParameters>(newDefaults: O) => _octokit_types.RequestInterface<object & O>;
        endpoint: _octokit_types.EndpointInterface<{
            url: string;
        }>;
    }, any>;
    updateWebhook: (key: IntegrationTaskKey, params: {
        owner: string;
        repo: string;
        hookId: number;
        url: string;
        secret: string;
        addEvents?: string[] | undefined;
    }) => GitHubReturnType<{
        (params?: (_octokit_types.RequestParameters & Omit<{
            owner: string;
            repo: string;
            hook_id: number;
        } & {
            config?: {
                url: string;
                content_type?: string | undefined;
                secret?: string | undefined;
                insecure_ssl?: string | number | undefined;
                address?: string | undefined;
                room?: string | undefined;
            } | undefined;
            events?: string[] | undefined;
            add_events?: string[] | undefined;
            remove_events?: string[] | undefined;
            active?: boolean | undefined;
        }, "headers" | "baseUrl" | "mediaType">) | undefined): Promise<_octokit_types.OctokitResponse<{
            type: string;
            id: number;
            name: string;
            active: boolean;
            events: string[];
            config: {
                email?: string | undefined;
                password?: string | undefined;
                room?: string | undefined;
                subdomain?: string | undefined;
                url?: string | undefined;
                insecure_ssl?: string | number | undefined;
                content_type?: string | undefined;
                digest?: string | undefined;
                secret?: string | undefined;
                token?: string | undefined;
            };
            updated_at: string;
            created_at: string;
            url: string;
            test_url: string;
            ping_url: string;
            deliveries_url?: string | undefined;
            last_response: {
                code: number | null;
                status: string | null;
                message: string | null;
            };
        }, 200>>;
        defaults: <O extends _octokit_types.RequestParameters = _octokit_types.RequestParameters>(newDefaults: O) => _octokit_types.RequestInterface<object & O>;
        endpoint: _octokit_types.EndpointInterface<{
            url: string;
        }>;
    }, any>;
    createWebhook: (key: IntegrationTaskKey, params: {
        owner: string;
        repo: string;
        url: string;
        secret: string;
        events: string[];
    }) => GitHubReturnType<{
        (params?: (_octokit_types.RequestParameters & Omit<{
            owner: string;
            repo: string;
        } & {
            name?: string | undefined;
            config?: {
                url?: string | undefined;
                content_type?: string | undefined;
                secret?: string | undefined;
                insecure_ssl?: string | number | undefined;
                token?: string | undefined;
                digest?: string | undefined;
            } | undefined;
            events?: string[] | undefined;
            active?: boolean | undefined;
        }, "headers" | "baseUrl" | "mediaType">) | undefined): Promise<_octokit_types.OctokitResponse<{
            type: string;
            id: number;
            name: string;
            active: boolean;
            events: string[];
            config: {
                email?: string | undefined;
                password?: string | undefined;
                room?: string | undefined;
                subdomain?: string | undefined;
                url?: string | undefined;
                insecure_ssl?: string | number | undefined;
                content_type?: string | undefined;
                digest?: string | undefined;
                secret?: string | undefined;
                token?: string | undefined;
            };
            updated_at: string;
            created_at: string;
            url: string;
            test_url: string;
            ping_url: string;
            deliveries_url?: string | undefined;
            last_response: {
                code: number | null;
                status: string | null;
                message: string | null;
            };
        }, 201>>;
        defaults: <O extends _octokit_types.RequestParameters = _octokit_types.RequestParameters>(newDefaults: O) => _octokit_types.RequestInterface<object & O>;
        endpoint: _octokit_types.EndpointInterface<{
            url: string;
        }>;
    }, any>;
    listWebhooks: (key: IntegrationTaskKey, params: {
        owner: string;
        repo: string;
    }) => GitHubReturnType<{
        (params?: (_octokit_types.RequestParameters & Omit<{
            owner: string;
            repo: string;
        } & {
            per_page?: number | undefined;
            page?: number | undefined;
        }, "headers" | "baseUrl" | "mediaType">) | undefined): Promise<_octokit_types.OctokitResponse<{
            type: string;
            id: number;
            name: string;
            active: boolean;
            events: string[];
            config: {
                email?: string | undefined;
                password?: string | undefined;
                room?: string | undefined;
                subdomain?: string | undefined;
                url?: string | undefined;
                insecure_ssl?: string | number | undefined;
                content_type?: string | undefined;
                digest?: string | undefined;
                secret?: string | undefined;
                token?: string | undefined;
            };
            updated_at: string;
            created_at: string;
            url: string;
            test_url: string;
            ping_url: string;
            deliveries_url?: string | undefined;
            last_response: {
                code: number | null;
                status: string | null;
                message: string | null;
            };
        }[], 200>>;
        defaults: <O extends _octokit_types.RequestParameters = _octokit_types.RequestParameters>(newDefaults: O) => _octokit_types.RequestInterface<object & O>;
        endpoint: _octokit_types.EndpointInterface<{
            url: string;
        }>;
    }, any>;
    addIssueCommentReaction: (key: IntegrationTaskKey, params: {
        owner: string;
        repo: string;
        commentId: number;
        content: ReactionContent;
    }) => GitHubReturnType<{
        (params?: (_octokit_types.RequestParameters & Omit<{
            owner: string;
            repo: string;
            comment_id: number;
        } & {
            content: "+1" | "-1" | "laugh" | "confused" | "heart" | "hooray" | "rocket" | "eyes";
        }, "headers" | "baseUrl" | "mediaType">) | undefined): Promise<_octokit_types.OctokitResponse<{
            id: number;
            node_id: string;
            user: {
                name?: string | null | undefined;
                email?: string | null | undefined;
                login: string;
                id: number;
                node_id: string;
                avatar_url: string;
                gravatar_id: string | null;
                url: string;
                html_url: string;
                followers_url: string;
                following_url: string;
                gists_url: string;
                starred_url: string;
                subscriptions_url: string;
                organizations_url: string;
                repos_url: string;
                events_url: string;
                received_events_url: string;
                type: string;
                site_admin: boolean;
                starred_at?: string | undefined;
            } | null;
            content: "+1" | "-1" | "laugh" | "confused" | "heart" | "hooray" | "rocket" | "eyes";
            created_at: string;
        }, 200> | _octokit_types.OctokitResponse<{
            id: number;
            node_id: string;
            user: {
                name?: string | null | undefined;
                email?: string | null | undefined;
                login: string;
                id: number;
                node_id: string;
                avatar_url: string;
                gravatar_id: string | null;
                url: string;
                html_url: string;
                followers_url: string;
                following_url: string;
                gists_url: string;
                starred_url: string;
                subscriptions_url: string;
                organizations_url: string;
                repos_url: string;
                events_url: string;
                received_events_url: string;
                type: string;
                site_admin: boolean;
                starred_at?: string | undefined;
            } | null;
            content: "+1" | "-1" | "laugh" | "confused" | "heart" | "hooray" | "rocket" | "eyes";
            created_at: string;
        }, 201>>;
        defaults: <O extends _octokit_types.RequestParameters = _octokit_types.RequestParameters>(newDefaults: O) => _octokit_types.RequestInterface<object & O>;
        endpoint: _octokit_types.EndpointInterface<{
            url: string;
        }>;
    }, any>;
    createIssueCommentWithReaction: (key: IntegrationTaskKey, params: {
        body: string;
        owner: string;
        repo: string;
        issueNumber: number;
        reaction: ReactionContent;
    }) => GitHubReturnType<{
        (params?: (_octokit_types.RequestParameters & Omit<{
            owner: string;
            repo: string;
            issue_number: number;
        } & {
            body: string;
        }, "headers" | "baseUrl" | "mediaType">) | undefined): Promise<_octokit_types.OctokitResponse<{
            id: number;
            node_id: string;
            url: string;
            body?: string | undefined;
            body_text?: string | undefined;
            body_html?: string | undefined;
            html_url: string;
            user: {
                name?: string | null | undefined;
                email?: string | null | undefined;
                login: string;
                id: number;
                node_id: string;
                avatar_url: string;
                gravatar_id: string | null;
                url: string;
                html_url: string;
                followers_url: string;
                following_url: string;
                gists_url: string;
                starred_url: string;
                subscriptions_url: string;
                organizations_url: string;
                repos_url: string;
                events_url: string;
                received_events_url: string;
                type: string;
                site_admin: boolean;
                starred_at?: string | undefined;
            } | null;
            created_at: string;
            updated_at: string;
            issue_url: string;
            author_association: "MEMBER" | "NONE" | "COLLABORATOR" | "CONTRIBUTOR" | "FIRST_TIMER" | "FIRST_TIME_CONTRIBUTOR" | "MANNEQUIN" | "OWNER";
            performed_via_github_app?: {
                id: number;
                slug?: string | undefined;
                node_id: string;
                owner: {
                    name?: string | null | undefined;
                    email?: string | null | undefined;
                    login: string;
                    id: number;
                    node_id: string;
                    avatar_url: string;
                    gravatar_id: string | null;
                    url: string;
                    html_url: string;
                    followers_url: string;
                    following_url: string;
                    gists_url: string;
                    starred_url: string;
                    subscriptions_url: string;
                    organizations_url: string;
                    repos_url: string;
                    events_url: string;
                    received_events_url: string;
                    type: string;
                    site_admin: boolean;
                    starred_at?: string | undefined;
                } | null;
                name: string;
                description: string | null;
                external_url: string;
                html_url: string;
                created_at: string;
                updated_at: string;
                permissions: {
                    [key: string]: string | undefined;
                    issues?: string | undefined;
                    checks?: string | undefined;
                    metadata?: string | undefined;
                    contents?: string | undefined;
                    deployments?: string | undefined;
                };
                events: string[];
                installations_count?: number | undefined;
                client_id?: string | undefined;
                client_secret?: string | undefined;
                webhook_secret?: string | null | undefined;
                pem?: string | undefined;
            } | null | undefined;
            reactions?: {
                url: string;
                total_count: number;
                "+1": number;
                "-1": number;
                laugh: number;
                confused: number;
                heart: number;
                hooray: number;
                eyes: number;
                rocket: number;
            } | undefined;
        }, 201>>;
        defaults: <O extends _octokit_types.RequestParameters = _octokit_types.RequestParameters>(newDefaults: O) => _octokit_types.RequestInterface<object & O>;
        endpoint: _octokit_types.EndpointInterface<{
            url: string;
        }>;
    }, any>;
    updateOrgWebhook: (key: IntegrationTaskKey, params: {
        org: string;
        hookId: number;
        url: string;
        secret: string;
        addEvents?: string[] | undefined;
    }) => GitHubReturnType<{
        (params?: (_octokit_types.RequestParameters & Omit<{
            org: string;
            hook_id: number;
        } & {
            config?: {
                url: string;
                content_type?: string | undefined;
                secret?: string | undefined;
                insecure_ssl?: string | number | undefined;
            } | undefined;
            events?: string[] | undefined;
            active?: boolean | undefined;
            name?: string | undefined;
        }, "headers" | "baseUrl" | "mediaType">) | undefined): Promise<_octokit_types.OctokitResponse<{
            id: number;
            url: string;
            ping_url: string;
            deliveries_url?: string | undefined;
            name: string;
            events: string[];
            active: boolean;
            config: {
                url?: string | undefined;
                insecure_ssl?: string | undefined;
                content_type?: string | undefined;
                secret?: string | undefined;
            };
            updated_at: string;
            created_at: string;
            type: string;
        }, 200>>;
        defaults: <O extends _octokit_types.RequestParameters = _octokit_types.RequestParameters>(newDefaults: O) => _octokit_types.RequestInterface<object & O>;
        endpoint: _octokit_types.EndpointInterface<{
            url: string;
        }>;
    }, any>;
    createOrgWebhook: (key: IntegrationTaskKey, params: {
        org: string;
        url: string;
        secret: string;
        events: string[];
    }) => GitHubReturnType<{
        (params?: (_octokit_types.RequestParameters & Omit<{
            org: string;
        } & {
            name: string;
            config: {
                url: string;
                content_type?: string | undefined;
                secret?: string | undefined;
                insecure_ssl?: string | number | undefined;
                username?: string | undefined;
                password?: string | undefined;
            };
            events?: string[] | undefined;
            active?: boolean | undefined;
        }, "headers" | "baseUrl" | "mediaType">) | undefined): Promise<_octokit_types.OctokitResponse<{
            id: number;
            url: string;
            ping_url: string;
            deliveries_url?: string | undefined;
            name: string;
            events: string[];
            active: boolean;
            config: {
                url?: string | undefined;
                insecure_ssl?: string | undefined;
                content_type?: string | undefined;
                secret?: string | undefined;
            };
            updated_at: string;
            created_at: string;
            type: string;
        }, 201>>;
        defaults: <O extends _octokit_types.RequestParameters = _octokit_types.RequestParameters>(newDefaults: O) => _octokit_types.RequestInterface<object & O>;
        endpoint: _octokit_types.EndpointInterface<{
            url: string;
        }>;
    }, any>;
    listOrgWebhooks: (key: IntegrationTaskKey, params: {
        org: string;
    }) => GitHubReturnType<{
        (params?: (_octokit_types.RequestParameters & Omit<{
            org: string;
        } & {
            per_page?: number | undefined;
            page?: number | undefined;
        }, "headers" | "baseUrl" | "mediaType">) | undefined): Promise<_octokit_types.OctokitResponse<{
            id: number;
            url: string;
            ping_url: string;
            deliveries_url?: string | undefined;
            name: string;
            events: string[];
            active: boolean;
            config: {
                url?: string | undefined;
                insecure_ssl?: string | undefined;
                content_type?: string | undefined;
                secret?: string | undefined;
            };
            updated_at: string;
            created_at: string;
            type: string;
        }[], 200>>;
        defaults: <O extends _octokit_types.RequestParameters = _octokit_types.RequestParameters>(newDefaults: O) => _octokit_types.RequestInterface<object & O>;
        endpoint: _octokit_types.EndpointInterface<{
            url: string;
        }>;
    }, any>;
    createBlob: (key: IntegrationTaskKey, params: {
        owner: string;
        repo: string;
        content: string;
        encoding?: ("utf-8" | "base-64") | undefined;
    }) => GitHubReturnType<{
        (params?: (_octokit_types.RequestParameters & Omit<{
            owner: string;
            repo: string;
        } & {
            content: string;
            encoding?: string | undefined;
        }, "headers" | "baseUrl" | "mediaType">) | undefined): Promise<_octokit_types.OctokitResponse<{
            url: string;
            sha: string;
        }, 201>>;
        defaults: <O extends _octokit_types.RequestParameters = _octokit_types.RequestParameters>(newDefaults: O) => _octokit_types.RequestInterface<object & O>;
        endpoint: _octokit_types.EndpointInterface<{
            url: string;
        }>;
    }, any>;
    getBlob: (key: IntegrationTaskKey, params: {
        owner: string;
        repo: string;
        fileSHA: string;
    }) => GitHubReturnType<{
        (params?: (_octokit_types.RequestParameters & Omit<{
            owner: string;
            repo: string;
            file_sha: string;
        }, "headers" | "baseUrl" | "mediaType">) | undefined): Promise<_octokit_types.OctokitResponse<{
            content: string;
            encoding: string;
            url: string;
            sha: string;
            size: number | null;
            node_id: string;
            highlighted_content?: string | undefined;
        }, 200>>;
        defaults: <O extends _octokit_types.RequestParameters = _octokit_types.RequestParameters>(newDefaults: O) => _octokit_types.RequestInterface<object & O>;
        endpoint: _octokit_types.EndpointInterface<{
            url: string;
        }>;
    }, any>;
    createCommit: (key: IntegrationTaskKey, params: {
        owner: string;
        repo: string;
        message: string;
        tree: string;
        parents?: string[] | undefined;
        author?: {
            name: string;
            email: string;
            date?: string | undefined;
        } | undefined;
        committer?: {
            name?: string | undefined;
            email?: string | undefined;
            date?: string | undefined;
        } | undefined;
        signature?: string | undefined;
    }) => GitHubReturnType<{
        (params?: (_octokit_types.RequestParameters & Omit<{
            owner: string;
            repo: string;
        } & {
            message: string;
            tree: string;
            parents?: string[] | undefined;
            author?: {
                name: string;
                email: string;
                date?: string | undefined;
            } | undefined;
            committer?: {
                name?: string | undefined;
                email?: string | undefined;
                date?: string | undefined;
            } | undefined;
            signature?: string | undefined;
        }, "headers" | "baseUrl" | "mediaType">) | undefined): Promise<_octokit_types.OctokitResponse<{
            sha: string;
            node_id: string;
            url: string;
            author: {
                date: string;
                email: string;
                name: string;
            };
            committer: {
                date: string;
                email: string;
                name: string;
            };
            message: string;
            tree: {
                sha: string;
                url: string;
            };
            parents: {
                sha: string;
                url: string;
                html_url: string;
            }[];
            verification: {
                verified: boolean;
                reason: string;
                signature: string | null;
                payload: string | null;
            };
            html_url: string;
        }, 201>>;
        defaults: <O extends _octokit_types.RequestParameters = _octokit_types.RequestParameters>(newDefaults: O) => _octokit_types.RequestInterface<object & O>;
        endpoint: _octokit_types.EndpointInterface<{
            url: string;
        }>;
    }, any>;
    getCommit: (key: IntegrationTaskKey, params: {
        owner: string;
        repo: string;
        commitSHA: string;
    }) => GitHubReturnType<{
        (params?: (_octokit_types.RequestParameters & Omit<{
            owner: string;
            repo: string;
            commit_sha: string;
        }, "headers" | "baseUrl" | "mediaType">) | undefined): Promise<_octokit_types.OctokitResponse<{
            sha: string;
            node_id: string;
            url: string;
            author: {
                date: string;
                email: string;
                name: string;
            };
            committer: {
                date: string;
                email: string;
                name: string;
            };
            message: string;
            tree: {
                sha: string;
                url: string;
            };
            parents: {
                sha: string;
                url: string;
                html_url: string;
            }[];
            verification: {
                verified: boolean;
                reason: string;
                signature: string | null;
                payload: string | null;
            };
            html_url: string;
        }, 200>>;
        defaults: <O extends _octokit_types.RequestParameters = _octokit_types.RequestParameters>(newDefaults: O) => _octokit_types.RequestInterface<object & O>;
        endpoint: _octokit_types.EndpointInterface<{
            url: string;
        }>;
    }, any>;
    listMatchingReferences: (key: IntegrationTaskKey, params: {
        owner: string;
        repo: string;
        ref: string;
    }) => GitHubReturnType<{
        (params?: (_octokit_types.RequestParameters & Omit<{
            owner: string;
            repo: string;
            ref: string;
        }, "headers" | "baseUrl" | "mediaType">) | undefined): Promise<_octokit_types.OctokitResponse<{
            ref: string;
            node_id: string;
            url: string;
            object: {
                type: string;
                sha: string;
                url: string;
            };
        }[], 200>>;
        defaults: <O extends _octokit_types.RequestParameters = _octokit_types.RequestParameters>(newDefaults: O) => _octokit_types.RequestInterface<object & O>;
        endpoint: _octokit_types.EndpointInterface<{
            url: string;
        }>;
    }, any>;
    getReference: (key: IntegrationTaskKey, params: {
        owner: string;
        repo: string;
        ref: string;
    }) => GitHubReturnType<{
        (params?: (_octokit_types.RequestParameters & Omit<{
            owner: string;
            repo: string;
            ref: string;
        }, "headers" | "baseUrl" | "mediaType">) | undefined): Promise<_octokit_types.OctokitResponse<{
            ref: string;
            node_id: string;
            url: string;
            object: {
                type: string;
                sha: string;
                url: string;
            };
        }, 200>>;
        defaults: <O extends _octokit_types.RequestParameters = _octokit_types.RequestParameters>(newDefaults: O) => _octokit_types.RequestInterface<object & O>;
        endpoint: _octokit_types.EndpointInterface<{
            url: string;
        }>;
    }, any>;
    createReference: (key: IntegrationTaskKey, params: {
        owner: string;
        repo: string;
        ref: string;
        sha: string;
    }) => GitHubReturnType<{
        (params?: (_octokit_types.RequestParameters & Omit<{
            owner: string;
            repo: string;
        } & {
            ref: string;
            sha: string;
            key?: string | undefined;
        }, "headers" | "baseUrl" | "mediaType">) | undefined): Promise<_octokit_types.OctokitResponse<{
            ref: string;
            node_id: string;
            url: string;
            object: {
                type: string;
                sha: string;
                url: string;
            };
        }, 201>>;
        defaults: <O extends _octokit_types.RequestParameters = _octokit_types.RequestParameters>(newDefaults: O) => _octokit_types.RequestInterface<object & O>;
        endpoint: _octokit_types.EndpointInterface<{
            url: string;
        }>;
    }, any>;
    updateReference: (key: IntegrationTaskKey, params: {
        owner: string;
        repo: string;
        ref: string;
        sha: string;
        force?: boolean | undefined;
    }) => GitHubReturnType<{
        (params?: (_octokit_types.RequestParameters & Omit<{
            owner: string;
            repo: string;
            ref: string;
        } & {
            sha: string;
            force?: boolean | undefined;
        }, "headers" | "baseUrl" | "mediaType">) | undefined): Promise<_octokit_types.OctokitResponse<{
            ref: string;
            node_id: string;
            url: string;
            object: {
                type: string;
                sha: string;
                url: string;
            };
        }, 200>>;
        defaults: <O extends _octokit_types.RequestParameters = _octokit_types.RequestParameters>(newDefaults: O) => _octokit_types.RequestInterface<object & O>;
        endpoint: _octokit_types.EndpointInterface<{
            url: string;
        }>;
    }, any>;
    deleteReference: (key: IntegrationTaskKey, params: {
        owner: string;
        repo: string;
        ref: string;
    }) => GitHubReturnType<{
        (params?: (_octokit_types.RequestParameters & Omit<{
            owner: string;
            repo: string;
            ref: string;
        }, "headers" | "baseUrl" | "mediaType">) | undefined): Promise<_octokit_types.OctokitResponse<never, 204>>;
        defaults: <O extends _octokit_types.RequestParameters = _octokit_types.RequestParameters>(newDefaults: O) => _octokit_types.RequestInterface<object & O>;
        endpoint: _octokit_types.EndpointInterface<{
            url: string;
        }>;
    }, any>;
    createTag: (key: IntegrationTaskKey, params: {
        owner: string;
        repo: string;
        tag: string;
        message: string;
        object: string;
        type: "commit" | "tree" | "blob";
        tagger?: {
            name: string;
            email: string;
            date?: string | undefined;
        } | undefined;
    }) => GitHubReturnType<{
        (params?: (_octokit_types.RequestParameters & Omit<{
            owner: string;
            repo: string;
        } & {
            tag: string;
            message: string;
            object: string;
            type: "commit" | "tree" | "blob";
            tagger?: {
                name: string;
                email: string;
                date?: string | undefined;
            } | undefined;
        }, "headers" | "baseUrl" | "mediaType">) | undefined): Promise<_octokit_types.OctokitResponse<{
            node_id: string;
            tag: string;
            sha: string;
            url: string;
            message: string;
            tagger: {
                date: string;
                email: string;
                name: string;
            };
            object: {
                sha: string;
                type: string;
                url: string;
            };
            verification?: {
                verified: boolean;
                reason: string;
                payload: string | null;
                signature: string | null;
            } | undefined;
        }, 201>>;
        defaults: <O extends _octokit_types.RequestParameters = _octokit_types.RequestParameters>(newDefaults: O) => _octokit_types.RequestInterface<object & O>;
        endpoint: _octokit_types.EndpointInterface<{
            url: string;
        }>;
    }, any>;
    getTag: (key: IntegrationTaskKey, params: {
        owner: string;
        repo: string;
        tagSHA: string;
    }) => GitHubReturnType<{
        (params?: (_octokit_types.RequestParameters & Omit<{
            owner: string;
            repo: string;
            tag_sha: string;
        }, "headers" | "baseUrl" | "mediaType">) | undefined): Promise<_octokit_types.OctokitResponse<{
            node_id: string;
            tag: string;
            sha: string;
            url: string;
            message: string;
            tagger: {
                date: string;
                email: string;
                name: string;
            };
            object: {
                sha: string;
                type: string;
                url: string;
            };
            verification?: {
                verified: boolean;
                reason: string;
                payload: string | null;
                signature: string | null;
            } | undefined;
        }, 200>>;
        defaults: <O extends _octokit_types.RequestParameters = _octokit_types.RequestParameters>(newDefaults: O) => _octokit_types.RequestInterface<object & O>;
        endpoint: _octokit_types.EndpointInterface<{
            url: string;
        }>;
    }, any>;
    createTree: (key: IntegrationTaskKey, params: {
        owner: string;
        repo: string;
        tree: {
            path?: string | undefined;
            mode?: "100644" | "100755" | "040000" | "160000" | "120000" | undefined;
            type?: "commit" | "tree" | "blob" | undefined;
            sha?: string | null | undefined;
            content?: string | undefined;
        }[];
        baseTree?: string | undefined;
    }) => GitHubReturnType<{
        (params?: (_octokit_types.RequestParameters & Omit<{
            owner: string;
            repo: string;
        } & {
            tree: {
                path?: string | undefined;
                mode?: "100644" | "100755" | "040000" | "160000" | "120000" | undefined;
                type?: "commit" | "tree" | "blob" | undefined;
                sha?: string | null | undefined;
                content?: string | undefined;
            }[];
            base_tree?: string | undefined;
        }, "headers" | "baseUrl" | "mediaType">) | undefined): Promise<_octokit_types.OctokitResponse<{
            sha: string;
            url: string;
            truncated: boolean;
            tree: {
                path?: string | undefined;
                mode?: string | undefined;
                type?: string | undefined;
                sha?: string | undefined;
                size?: number | undefined;
                url?: string | undefined;
            }[];
        }, 201>>;
        defaults: <O extends _octokit_types.RequestParameters = _octokit_types.RequestParameters>(newDefaults: O) => _octokit_types.RequestInterface<object & O>;
        endpoint: _octokit_types.EndpointInterface<{
            url: string;
        }>;
    }, any>;
    getTree: (key: IntegrationTaskKey, params: {
        owner: string;
        repo: string;
        treeSHA: string;
        recursive?: string | undefined;
    }) => GitHubReturnType<{
        (params?: (_octokit_types.RequestParameters & Omit<{
            owner: string;
            repo: string;
            tree_sha: string;
        } & {
            recursive?: string | undefined;
        }, "headers" | "baseUrl" | "mediaType">) | undefined): Promise<_octokit_types.OctokitResponse<{
            sha: string;
            url: string;
            truncated: boolean;
            tree: {
                path?: string | undefined;
                mode?: string | undefined;
                type?: string | undefined;
                sha?: string | undefined;
                size?: number | undefined;
                url?: string | undefined;
            }[];
        }, 200>>;
        defaults: <O extends _octokit_types.RequestParameters = _octokit_types.RequestParameters>(newDefaults: O) => _octokit_types.RequestInterface<object & O>;
        endpoint: _octokit_types.EndpointInterface<{
            url: string;
        }>;
    }, any>;
}
declare const events: {
    /** When any action is performed on an issue  */
    onIssue: EventSpecification<IssuesEvent>;
    /** When an issue is opened  */
    onIssueOpened: EventSpecification<IssuesOpenedEvent>;
    /** When an issue is assigned  */
    onIssueAssigned: EventSpecification<IssuesAssignedEvent>;
    /** When an issue is commented on  */
    onIssueComment: EventSpecification<IssueCommentEvent>;
    /** When a repo is starred or unstarred  */
    onStar: EventSpecification<StarEvent>;
    /** When a repo is starred  */
    onNewStar: EventSpecification<StarCreatedEvent>;
    /** When a new repo is created  */
    onNewRepository: EventSpecification<RepositoryCreatedEvent>;
    /** When a new branch or tag is created  */
    onNewBranchOrTag: EventSpecification<CreateEvent>;
    /** When a new branch is created  */
    onNewBranch: EventSpecification<CreateEvent>;
    /** When a push is made to a repo  */
    onPush: EventSpecification<PushEvent>;
    /** When activity occurs on a pull request. Doesn't include reviews, issues or comments. */
    onPullRequest: EventSpecification<PullRequestEvent>;
    /** When Pull Request review has activity. */
    onPullRequestReview: EventSpecification<PullRequestReviewEvent>;
};
type GitHubEvents = (typeof events)[keyof typeof events];
type CreateRepoTriggerReturnType = <TEventSpecification extends GitHubEvents>(args: {
    event: TEventSpecification;
    owner: string;
    repo: string;
}) => ExternalSourceTrigger<TEventSpecification, ReturnType<typeof createRepoEventSource>>;
declare function createRepoTrigger(source: ReturnType<typeof createRepoEventSource>): CreateRepoTriggerReturnType;
type CreateOrgTriggerReturnType = <TEventSpecification extends GitHubEvents>(args: {
    event: TEventSpecification;
    org: string;
}) => ExternalSourceTrigger<TEventSpecification, ReturnType<typeof createOrgEventSource>>;
declare function createOrgTrigger(source: ReturnType<typeof createOrgEventSource>): CreateOrgTriggerReturnType;
declare function isRequestError(error: unknown): error is RequestError;
declare function onError(error: unknown): {
    retryAt: Date;
    error: RequestError;
} | undefined;

export { GitHubReturnType, GitHubRunTask, Github, GithubIntegrationOptions, events, isRequestError, onError };
